@@ -994,8 +994,6 @@ done:
     return ret_value;
 }
 
-
-#ifdef NEW_HYPERSLAB_API
 /****if* H5Sf/h5scombine_hyperslab_c
  * NAME
  *  h5scombine_hyperslab_c
@@ -1118,11 +1116,11 @@ h5scombine_select_c ( hid_t_f *space1_id , int_f *op, hid_t_f *space2_id, hid_t_
   ret_value = 0;
   return ret_value;
 }
-/****if* H5Sf/h5sselect_select_c
+/****if* H5Sf/h5smodify_select_c
  * NAME
- *  h5sselect_select_c
+ *  h5smodify_select_c
  * PURPOSE
- *  Call H5Sselect_ select
+ *  Call H5Smodify_select
  * INPUTS
  *  space1_id - identifier of the first dataspace  to modify
  *  operator - defines how the new selection is combined
@@ -1138,7 +1136,7 @@ h5scombine_select_c ( hid_t_f *space1_id , int_f *op, hid_t_f *space2_id, hid_t_
 */
 
 int_f
-h5sselect_select_c ( hid_t_f *space1_id , int_f *op, hid_t_f *space2_id)
+h5smodify_select_c ( hid_t_f *space1_id , int_f *op, hid_t_f *space2_id)
 /******/
 {
   int ret_value = -1;
@@ -1150,11 +1148,11 @@ h5sselect_select_c ( hid_t_f *space1_id , int_f *op, hid_t_f *space2_id)
 
   c_space1_id = (hid_t)*space1_id;
   c_space2_id = (hid_t)*space2_id;
-  if( H5Sselect_select(c_space1_id, c_op, c_space2_id)< 0) return ret_value;
+  if( H5Smodify_select(c_space1_id, c_op, c_space2_id)< 0) return ret_value;
   ret_value = 0;
   return ret_value;
 }
-#endif /*NEW_HYPERSLAB_API*/
+
 /****if* H5Sf/h5sget_select_type_c
  * NAME
  *  h5sget_select_type_c
