@@ -131,7 +131,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1name
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (NULL == (namePtr = (char *) HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
-        H5_JNI_FATAL_ERROR(ENVONLY, "H5Fget_name: malloc failed");
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_name: malloc failed");
 
     if ((H5Fget_name((hid_t)file_id, namePtr, (size_t)buf_size + 1)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
@@ -386,7 +386,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids
     }
 
     if (NULL == (id_list = (hid_t *) HDmalloc((size_t)rank * sizeof(hid_t))))
-        H5_JNI_FATAL_ERROR(ENVONLY, "H5Fget_obj_ids: malloc failed");
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_obj_ids: malloc failed");
 
     if ((ret_val = H5Fget_obj_ids((hid_t)file_id, (unsigned int)types, (size_t)maxObjs, id_list)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
