@@ -308,7 +308,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1family
     }
 
     if (NULL == (sa = (hsize_t *) HDmalloc((size_t) rank * sizeof(hsize_t))))
-        H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_family: memory allocation failed");
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_family: memory allocation failed");
 
     PIN_LONG_ARRAY(ENVONLY, memb_plist, plistArray, &isCopy, "H5Pget_family: plistArray not pinned");
 
@@ -395,29 +395,23 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1hdfs
     if (H5Pget_fapl_hdfs((hid_t)fapl_id, &fa) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (NULL != fa.namenode_name) {
-        if (NULL == (j_namenode_name = ENVPTR->NewStringUTF(ENVONLY, fa.namenode_name))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create namenode_name string");
-        }
+    if (NULL == (j_namenode_name = ENVPTR->NewStringUTF(ENVONLY, fa.namenode_name))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create namenode_name string");
     }
     args[0].l = j_namenode_name;
 
     args[1].i = (jint)fa.namenode_port;
 
-    if (NULL != fa.user_name) {
-        if (NULL == (j_user_name = ENVPTR->NewStringUTF(ENVONLY, fa.user_name))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create user_name string");
-        }
+    if (NULL == (j_user_name = ENVPTR->NewStringUTF(ENVONLY, fa.user_name))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create user_name string");
     }
     args[2].l = j_user_name;
 
-    if (NULL != fa.kerberos_ticket_cache) {
-        if (NULL == (j_kerb_cache_path = ENVPTR->NewStringUTF(ENVONLY, fa.kerberos_ticket_cache))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create kerberos_ticket_cache string");
-        }
+    if (NULL == (j_kerb_cache_path = ENVPTR->NewStringUTF(ENVONLY, fa.kerberos_ticket_cache))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_hdfs: out of memory - can't create kerberos_ticket_cache string");
     }
     args[3].l = j_kerb_cache_path;
 
@@ -425,6 +419,8 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1hdfs
 
     CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5FD_hdfs_fapl_t", "(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;I)V", args, ret_obj);
 #else
+    UNUSED(fapl_id);
+
     H5_UNIMPLEMENTED(ENVONLY, "H5Pget_fapl_hdfs: not implemented");
 #endif /* H5_HAVE_LIBHDFS */
 
@@ -532,6 +528,9 @@ Java_hdf_hdf5lib_H5_H5Pset_1fapl_1hdfs
     if (H5Pset_fapl_hdfs((hid_t)fapl_id, &instance) < 0)
             H5_LIBRARY_ERROR(ENVONLY);
 #else
+    UNUSED(fapl_id);
+    UNUSED(fapl_config);
+
     H5_UNIMPLEMENTED(ENVONLY, "H5Pset_fapl_hdfs: not implemented");
 #endif /* H5_HAVE_LIBHDFS */
 
@@ -646,7 +645,7 @@ Java_hdf_hdf5lib_H5_H5Pset_1fapl_1multi
             str_len = HDstrlen(utf8);
 
             if (NULL == (member_name[i] = (char *) HDmalloc(str_len + 1)))
-                H5_JNI_FATAL_ERROR(ENVONLY, "H5Pset_fapl_multi: memory allocation failed");
+                H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pset_fapl_multi: memory allocation failed");
 
             HDstrncpy(member_name[i], utf8, str_len + 1);
             (member_name[i])[str_len] = '\0';
@@ -673,7 +672,7 @@ Java_hdf_hdf5lib_H5_H5Pset_1fapl_1multi
 
             if (NULL == (rstring = ENVPTR->NewStringUTF(ENVONLY, member_name[i]))) {
                 CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-                H5_JNI_FATAL_ERROR(ENVONLY, "H5Pset_fapl_multi: out of memory - unable to construct string from UTF characters");
+                H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pset_fapl_multi: out of memory - unable to construct string from UTF characters");
             }
 
             if (NULL == (o = ENVPTR->GetObjectArrayElement(ENVONLY, memb_name, (jsize) i))) {
@@ -745,7 +744,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1multi
         PIN_LONG_ARRAY(ENVONLY, memb_addr, theaddrArray, &isCopy, "H5Pget_fapl_multi: memb_addr not pinned");
     if (memb_name)
         if (NULL == (mName = (char **) HDcalloc(H5FD_MEM_NTYPES, sizeof(*mName))))
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_multi: memory allocation failed");
+            H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_multi: memory allocation failed");
 
     if ((status = H5Pget_fapl_multi((hid_t)tid, (H5FD_mem_t *)themapArray, (hid_t *)thefaplArray,
             mName, (haddr_t *)theaddrArray, (hbool_t *)&relax)) < 0)
@@ -756,7 +755,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1multi
             if (mName[i]) {
                 if (NULL == (str = ENVPTR->NewStringUTF(ENVONLY, mName[i]))) {
                     CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-                    H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_multi: out of memory - unable to construct string from UTF characters");
+                    H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_multi: out of memory - unable to construct string from UTF characters");
                 }
 
                 ENVPTR->SetObjectArrayElement(ENVONLY, memb_name, (jsize) i, (jobject)str);
@@ -815,32 +814,28 @@ Java_hdf_hdf5lib_H5_H5Pget_1fapl_1ros3
     if (H5Pget_fapl_ros3((hid_t)fapl_id, &fa) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (NULL != fa.aws_region) {
-        if (NULL == (j_aws = ENVPTR->NewStringUTF(ENVONLY, fa.aws_region))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create aws_region string");
-        }
+    if (NULL == (j_aws = ENVPTR->NewStringUTF(ENVONLY, fa.aws_region))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create aws_region string");
     }
     args[0].l = j_aws;
 
-    if (NULL != fa.secret_id) {
-        if (NULL == (j_id = ENVPTR->NewStringUTF(ENVONLY, fa.secret_id))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create secret_id string");
-        }
+    if (NULL == (j_id = ENVPTR->NewStringUTF(ENVONLY, fa.secret_id))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create secret_id string");
     }
     args[1].l = j_id;
 
-    if (NULL != fa.secret_key) {
-        if (NULL == (j_key = ENVPTR->NewStringUTF(ENVONLY, fa.secret_key))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create secret_key string");
-        }
+    if (NULL == (j_key = ENVPTR->NewStringUTF(ENVONLY, fa.secret_key))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_fapl_ros3: out of memory - can't create secret_key string");
     }
     args[2].l = j_key;
 
     CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5FD_ros3_fapl_t", "(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)V", args, ret_obj);
 #else
+    UNUSED(fapl_id);
+
     H5_UNIMPLEMENTED(ENVONLY, "H5Pget_fapl_ros3: not implemented");
 #endif /* H5_HAVE_ROS3_VFD */
 
@@ -939,6 +934,9 @@ Java_hdf_hdf5lib_H5_H5Pset_1fapl_1ros3
     if (H5Pset_fapl_ros3((hid_t)fapl_id, &instance) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 #else
+    UNUSED(fapl_id);
+    UNUSED(fapl_config);
+
     H5_UNIMPLEMENTED(ENVONLY, "H5Pset_fapl_ros3: not implemented");
 #endif /* H5_HAVE_ROS3_VFD */
 
@@ -1377,6 +1375,78 @@ done:
     return bval;
 } /* end Java_hdf_hdf5lib_H5_H5Pget_1evict_1on_1close */
 
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Pset_file_locking
+ * Signature: (JZZ)V
+ */
+JNIEXPORT void JNICALL
+Java_hdf_hdf5lib_H5_H5Pset_1file_1locking
+    (JNIEnv *env, jclass clss, jlong fapl_id, jboolean use_file_locking, jboolean ignore_when_disabled)
+{
+    hbool_t use_file_locking_val = TRUE;
+    hbool_t ignore_when_disabled_val = TRUE;
+
+    UNUSED(clss);
+
+    use_file_locking_val = (use_file_locking == JNI_TRUE) ? TRUE : FALSE;
+    ignore_when_disabled_val = (ignore_when_disabled == JNI_TRUE) ? TRUE : FALSE;
+
+    if (H5Pset_file_locking((hid_t)fapl_id, use_file_locking_val, ignore_when_disabled_val) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+done:
+    return;
+} /* end Java_hdf_hdf5lib_H5_H5Pset_1file_1locking */
+
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Pget_use_file_locking
+ * Signature: (J)Z
+ */
+JNIEXPORT jboolean JNICALL
+Java_hdf_hdf5lib_H5_H5Pget_1use_1file_1locking
+    (JNIEnv *env, jclass clss, jlong fapl_id)
+{
+    hbool_t     use_file_locking_val    = TRUE;
+    hbool_t     unused                  = TRUE;
+    jboolean    bval                    = JNI_FALSE;
+
+    UNUSED(clss);
+
+    if (H5Pget_file_locking((hid_t)fapl_id, &use_file_locking_val, &unused) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+    bval = (use_file_locking_val == TRUE) ? JNI_TRUE : JNI_FALSE;
+
+done:
+    return bval;
+} /* end Java_hdf_hdf5lib_H5_H5Pget_1use_1file_1locking */
+
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Pget_ignore_disabled_file_locking
+ * Signature: (J)Z
+ */
+JNIEXPORT jboolean JNICALL
+Java_hdf_hdf5lib_H5_H5Pget_1ignore_1disabled_1file_1locking
+    (JNIEnv *env, jclass clss, jlong fapl_id)
+{
+    hbool_t     ignore_when_disabled_val    = TRUE;
+    hbool_t     unused                      = TRUE;
+    jboolean    bval                        = JNI_FALSE;
+
+    UNUSED(clss);
+
+    if (H5Pget_file_locking((hid_t)fapl_id, &unused, &ignore_when_disabled_val) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+    bval = (ignore_when_disabled_val == TRUE) ? JNI_TRUE : JNI_FALSE;
+
+done:
+    return bval;
+} /* end Java_hdf_hdf5lib_H5_H5Pget_1ignore_1disabled_1file_1locking */
+
 /*
  * Class:     hdf_hdf5lib_H5
  * Method:    H5Pset_metadata_read_attempts
@@ -1675,11 +1745,9 @@ Java_hdf_hdf5lib_H5_H5Pget_1mdc_1config
     args[2].z = cacheinfo.open_trace_file;
     args[3].z = cacheinfo.close_trace_file;
 
-    if (NULL != cacheinfo.trace_file_name) {
-        if (NULL == (j_str = ENVPTR->NewStringUTF(ENVONLY, cacheinfo.trace_file_name))) {
-            CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-            H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_mdc_config: out of memory - unable to construct string from UTF characters");
-        }
+    if (NULL == (j_str = ENVPTR->NewStringUTF(ENVONLY, cacheinfo.trace_file_name))) {
+        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_mdc_config: out of memory - unable to construct string from UTF characters");
     }
 
     args[4].l = j_str;
@@ -1792,7 +1860,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1mdc_1log_1options
 
     location_size++; /* add extra space for the null terminator */
     if (NULL == (lname = (char *) HDmalloc(sizeof(char) * location_size)))
-        H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_mdc_log_options: memory allocation failed");
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_mdc_log_options: memory allocation failed");
 
     if ((status = H5Pget_mdc_log_options((hid_t)fapl_id, &is_enabled, lname, &location_size, &start_on_access)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
@@ -1800,7 +1868,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1mdc_1log_1options
 
     if (NULL == (str = ENVPTR->NewStringUTF(ENVONLY, lname))) {
         CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-        H5_JNI_FATAL_ERROR(ENVONLY, "H5Pget_mdc_log_options: out of memory - unable to construct string from UTF characters");
+        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_mdc_log_options: out of memory - unable to construct string from UTF characters");
     }
 
     mdc_log_options_ptr[0] = (jboolean)is_enabled;
