@@ -40,13 +40,20 @@ JNIEXPORT jint JNICALL
 Java_hdf_hdf5lib_H5_H5Pget_1version
     (JNIEnv *env, jclass clss, jlong plist, jintArray version_info)
 {
+#ifndef H5_NO_DEPRECATED_SYMBOLS
     jboolean  isCopy;
     jsize     arrLen;
     jint     *theArray = NULL;
+#endif
     herr_t    status = FAIL;
 
     UNUSED(clss);
 
+#ifdef H5_NO_DEPRECATED_SYMBOLS
+    UNUSED(plist);
+    UNUSED(version_info);
+    H5_UNIMPLEMENTED(ENVONLY, "H5Pget_version: not implemented");
+#else
     if (NULL == version_info)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Pget_version: version_info input array is NULL");
 
@@ -62,10 +69,13 @@ Java_hdf_hdf5lib_H5_H5Pget_1version
     if ((status = H5Pget_version((hid_t)plist, (unsigned *)&(theArray[0]),
             (unsigned *)&(theArray[1]), (unsigned *)&(theArray[2]), (unsigned *)&(theArray[3]))) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
+#endif
 
 done:
+#ifndef H5_NO_DEPRECATED_SYMBOLS
     if (theArray)
         UNPIN_INT_ARRAY(ENVONLY, version_info, theArray, (status < 0) ? JNI_ABORT : 0);
+#endif
 
     return (jint)status;
 } /* end Java_hdf_hdf5lib_H5_H5Pget_1version */
