@@ -15,7 +15,7 @@
  *
  * Created:		H5EAcache.c
  *			Aug 26 2008
- *			Quincey Koziol <koziol@hdfgroup.org>
+ *			Quincey Koziol
  *
  * Purpose:		Implement extensible array metadata cache methods.
  *
@@ -41,6 +41,7 @@
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5EApkg.h"		/* Extensible Arrays			*/
 #include "H5MFprivate.h"	/* File memory management		*/
+#include "H5MMprivate.h"	/* Memory management			*/
 #include "H5VMprivate.h"	/* Vectors and arrays 			*/
 #include "H5WBprivate.h"        /* Wrapped Buffers                      */
 
@@ -116,7 +117,7 @@ static herr_t H5EA__cache_dblk_page_get_initial_load_size(void *udata, size_t *i
 static htri_t H5EA__cache_dblk_page_verify_chksum(const void *image_ptr, size_t len, void *udata_ptr);
 static void *H5EA__cache_dblk_page_deserialize(const void *image, size_t len,
     void *udata, hbool_t *dirty);
-static herr_t H5EA__cache_dblk_page_image_len(const void *thing, 
+static herr_t H5EA__cache_dblk_page_image_len(const void *thing,
     size_t *image_len);
 static herr_t H5EA__cache_dblk_page_serialize(const H5F_t *f, void *image, size_t len,
     void *thing);
@@ -238,7 +239,6 @@ const H5AC_class_t H5AC_EARRAY_DBLK_PAGE[1] = {{
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 16, 2013
  *
  *-------------------------------------------------------------------------
@@ -304,7 +304,6 @@ END_FUNC(STATIC) 	/* end H5EA__cache_hdr_verify_chksum() */
  *		Failure:	NULL
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 16, 2013
  *
  *-------------------------------------------------------------------------
@@ -428,7 +427,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_hdr_deserialize() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 16, 2013
  *
  *-------------------------------------------------------------------------
@@ -458,7 +456,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_hdr_image_len() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 16, 2013
  *
  *-------------------------------------------------------------------------
@@ -479,14 +476,15 @@ H5EA__cache_hdr_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED le
     HDassert(hdr);
 
     /* Magic number */
-    HDmemcpy(image, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC);
+    H5MM_memcpy(image, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC);
     image += H5_SIZEOF_MAGIC;
 
     /* Version # */
     *image++ = H5EA_HDR_VERSION;
 
     /* Extensible array type */
-    *image++ = hdr->cparam.cls->id;
+    HDassert(hdr->cparam.cls->id <= 255);
+    *image++ = (uint8_t)hdr->cparam.cls->id;
 
     /* General array creation/configuration information */
     *image++ = hdr->cparam.raw_elmt_size;          /* Element size in file (in bytes) */
@@ -604,7 +602,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_hdr_notify() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 16, 2013
  *
  *-------------------------------------------------------------------------
@@ -633,7 +630,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_hdr_free_icr() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -706,7 +702,6 @@ END_FUNC(STATIC) 	/* end H5EA__cache_iblock_verify_chksum() */
  *		Failure:	NULL
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -813,7 +808,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_iblock_deserialize() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -843,7 +837,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_iblock_image_len() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -867,14 +860,15 @@ H5EA__cache_iblock_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED
     /* Get temporary pointer to serialized info */
 
     /* Magic number */
-    HDmemcpy(image, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
+    H5MM_memcpy(image, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
     image += H5_SIZEOF_MAGIC;
 
     /* Version # */
     *image++ = H5EA_IBLOCK_VERSION;
 
     /* Extensible array type */
-    *image++ = iblock->hdr->cparam.cls->id;
+    HDassert(iblock->hdr->cparam.cls->id <= 255);
+    *image++ = (uint8_t)iblock->hdr->cparam.cls->id;
 
     /* Address of array header for array which owns this block */
     H5F_addr_encode(f, &image, iblock->hdr->addr);
@@ -929,7 +923,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_iblock_serialize() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -998,7 +991,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_iblock_notify() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1027,7 +1019,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_iblock_free_icr() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1119,7 +1110,6 @@ END_FUNC(STATIC) 	/* end H5EA__cache_sblock_verify_chksum() */
  *		Failure:	NULL
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1179,7 +1169,7 @@ H5EA__cache_sblock_deserialize(const void *_image, size_t len,
         size_t tot_page_init_size = sblock->ndblks * sblock->dblk_page_init_size;        /* Compute total size of 'page init' buffer */
 
         /* Retrieve the 'page init' bitmasks */
-        HDmemcpy(sblock->page_init, image, tot_page_init_size);
+        H5MM_memcpy(sblock->page_init, image, tot_page_init_size);
         image += tot_page_init_size;
     } /* end if */
 
@@ -1223,7 +1213,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_sblock_deserialize() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1253,7 +1242,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_sblock_image_len() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1276,14 +1264,15 @@ H5EA__cache_sblock_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED
     HDassert(sblock->hdr);
 
     /* Magic number */
-    HDmemcpy(image, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
+    H5MM_memcpy(image, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
     image += H5_SIZEOF_MAGIC;
 
     /* Version # */
     *image++ = H5EA_SBLOCK_VERSION;
 
     /* Extensible array type */
-    *image++ = sblock->hdr->cparam.cls->id;
+    HDassert(sblock->hdr->cparam.cls->id <= 255);
+    *image++ = (uint8_t)sblock->hdr->cparam.cls->id;
 
     /* Address of array header for array which owns this block */
     H5F_addr_encode(f, &image, sblock->hdr->addr);
@@ -1298,7 +1287,7 @@ H5EA__cache_sblock_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED
         size_t tot_page_init_size = sblock->ndblks * sblock->dblk_page_init_size;        /* Compute total size of 'page init' buffer */
 
         /* Store the 'page init' bitmasks */
-        HDmemcpy(image, sblock->page_init, tot_page_init_size);
+        H5MM_memcpy(image, sblock->page_init, tot_page_init_size);
         image += tot_page_init_size;
     } /* end if */
 
@@ -1326,7 +1315,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_sblock_serialize() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Mar 31 2009
  *
  *-------------------------------------------------------------------------
@@ -1410,7 +1398,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_sblock_notify() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1439,7 +1426,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_sblock_free_icr() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1463,12 +1449,12 @@ H5EA__cache_dblock_get_initial_load_size(void *_udata, size_t *image_len))
     HDmemset(&dblock, 0, sizeof(dblock));
 
     /* need to set:
-     * 
+     *
      *    dblock.hdr
      *    dblock.npages
      *    dblock.nelmts
      *
-     * before we invoke either H5EA_DBLOCK_PREFIX_SIZE() or 
+     * before we invoke either H5EA_DBLOCK_PREFIX_SIZE() or
      * H5EA_DBLOCK_SIZE().
      */
     dblock.hdr = udata->hdr;
@@ -1532,14 +1518,13 @@ END_FUNC(STATIC) 	/* end H5EA__cache_sblock_verify_chksum() */
  *		Failure:	NULL
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
  */
 BEGIN_FUNC(STATIC, ERR,
 void *, NULL, NULL,
-H5EA__cache_dblock_deserialize(const void *_image, size_t len,
+H5EA__cache_dblock_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED len,
     void *_udata, hbool_t H5_ATTR_UNUSED *dirty))
 
     /* Local variables */
@@ -1560,7 +1545,7 @@ H5EA__cache_dblock_deserialize(const void *_image, size_t len,
     if(NULL == (dblock = H5EA__dblock_alloc(udata->hdr, udata->parent, udata->nelmts)))
 	H5E_THROW(H5E_CANTALLOC, "memory allocation failed for extensible array data block")
 
-    HDassert(((!dblock->npages) && (len == H5EA_DBLOCK_SIZE(dblock))) || 
+    HDassert(((!dblock->npages) && (len == H5EA_DBLOCK_SIZE(dblock))) ||
              (len == H5EA_DBLOCK_PREFIX_SIZE(dblock)));
 
     /* Set the extensible array data block's information */
@@ -1635,7 +1620,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblock_deserialize() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1668,7 +1652,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblock_image_len() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1690,14 +1673,15 @@ H5EA__cache_dblock_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED
     HDassert(dblock->hdr);
 
     /* Magic number */
-    HDmemcpy(image, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
+    H5MM_memcpy(image, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC);
     image += H5_SIZEOF_MAGIC;
 
     /* Version # */
     *image++ = H5EA_DBLOCK_VERSION;
 
     /* Extensible array type */
-    *image++ = dblock->hdr->cparam.cls->id;
+    HDassert(dblock->hdr->cparam.cls->id <= 255);
+    *image++ = (uint8_t)dblock->hdr->cparam.cls->id;
 
     /* Address of array header for array which owns this block */
     H5F_addr_encode(f, &image, dblock->hdr->addr);
@@ -1739,7 +1723,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblock_serialize() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Mar 31 2009
  *
  *-------------------------------------------------------------------------
@@ -1823,7 +1806,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblock_notify() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1899,7 +1881,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblock_fsf_size() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -1965,7 +1946,6 @@ END_FUNC(STATIC) 	/* end H5EA__cache_dblk_page_verify_chksum() */
  *		Failure:	NULL
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -2038,7 +2018,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblk_page_deserialize() */
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
@@ -2068,14 +2047,13 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblk_page_image_len() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
  */
 BEGIN_FUNC(STATIC, ERR,
 herr_t, SUCCEED, FAIL,
-H5EA__cache_dblk_page_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_UNUSED len,
+H5EA__cache_dblk_page_serialize(const H5F_t H5_ATTR_NDEBUG_UNUSED *f, void *_image, size_t H5_ATTR_UNUSED len,
     void *_thing))
 
     /* Local variables */
@@ -2120,7 +2098,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblk_page_serialize() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Mar 31 2009
  *
  *-------------------------------------------------------------------------
@@ -2204,7 +2181,6 @@ END_FUNC(STATIC)   /* end H5EA__cache_dblk_page_notify() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *              koziol@hdfgroup.org
  *              July 17, 2013
  *
  *-------------------------------------------------------------------------
