@@ -15,7 +15,7 @@
  *
  * Created:		H5EAhdr.c
  *			Aug 26 2008
- *			Quincey Koziol <koziol@hdfgroup.org>
+ *			Quincey Koziol
  *
  * Purpose:		Array header routines for extensible arrays.
  *
@@ -41,6 +41,7 @@
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5EApkg.h"		/* Extensible Arrays			*/
 #include "H5MFprivate.h"	/* File memory management		*/
+#include "H5MMprivate.h"	/* Memory management			*/
 #include "H5VMprivate.h"	/* Vectors and arrays 			*/
 
 
@@ -62,6 +63,9 @@
 /* Local Typedefs */
 /******************/
 
+/* Alias for pointer to factory, for use when allocating sequences of them */
+typedef H5FL_fac_head_t *H5FL_fac_head_ptr_t;
+
 
 /********************/
 /* Package Typedefs */
@@ -82,9 +86,6 @@
 /* Library Private Variables */
 /*****************************/
 
-/* Alias for pointer to factory, for use when allocating sequences of them */
-typedef H5FL_fac_head_t *H5FL_fac_head_ptr_t;
-
 
 /*******************/
 /* Local Variables */
@@ -109,7 +110,6 @@ H5FL_SEQ_DEFINE_STATIC(H5EA_sblk_info_t);
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -179,7 +179,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_alloc() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Sep 18 2008
  *
  *-------------------------------------------------------------------------
@@ -244,7 +243,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_init() */
  * Return:	Non-NULL pointer to buffer for elements on success/NULL on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Sep 16 2008
  *
  *-------------------------------------------------------------------------
@@ -311,7 +309,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_alloc_elmts() */
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Sep 18 2008
  *
  *-------------------------------------------------------------------------
@@ -348,7 +345,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_free_elmts() */
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jun 17 2008
  *
  *-------------------------------------------------------------------------
@@ -407,7 +403,7 @@ H5EA__hdr_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata))
     hdr->idx_blk_addr = HADDR_UNDEF;
 
     /* Set the creation parameters for the array */
-    HDmemcpy(&hdr->cparam, cparam, sizeof(hdr->cparam));
+    H5MM_memcpy(&hdr->cparam, cparam, sizeof(hdr->cparam));
 
     /* Finish initializing extensible array header */
     if(H5EA__hdr_init(hdr, ctx_udata) < 0)
@@ -463,7 +459,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_create() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -496,7 +491,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_incr() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -532,7 +526,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_decr() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -558,7 +551,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_fuse_incr() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -588,7 +580,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_fuse_decr() */
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Sep  9 2008
  *
  *-------------------------------------------------------------------------
@@ -618,7 +609,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_modified() */
  * Return:	Non-NULL pointer to header on success/NULL on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jul 31 2013
  *
  *-------------------------------------------------------------------------
@@ -676,7 +666,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_protect() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug  1 2013
  *
  *-------------------------------------------------------------------------
@@ -707,7 +696,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_unprotect() */
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
@@ -764,7 +752,6 @@ END_FUNC(PKG)   /* end H5EA__hdr_delete() */
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Sep 11 2008
  *
  *-------------------------------------------------------------------------
