@@ -12,7 +12,7 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Tuesday, August 10, 1999
  *
  * Purpose:     A driver which stores the HDF5 data in main memory  using
@@ -36,6 +36,9 @@
 /* The driver identification number, initialized at runtime */
 static hid_t H5FD_CORE_g = 0;
 
+/* Whether to ignore file locks when disabled (env var value) */
+static htri_t ignore_disabled_file_locks_s = FAIL;
+
 /* The skip list node type.  Represents a region in the file. */
 typedef struct H5FD_core_region_t {
     haddr_t start;              /* Start address of the region          */
@@ -55,6 +58,7 @@ typedef struct H5FD_core_t {
     size_t  increment;          /* multiples for mem allocation         */
     hbool_t backing_store;      /* write to file name on flush          */
     size_t  bstore_page_size;   /* backing store page size              */
+    hbool_t ignore_disabled_file_locks;
     int     fd;                 /* backing store file descriptor        */
     /* Information for determining uniqueness of a file with a backing store */
 #ifndef H5_HAVE_WIN32_API
@@ -81,7 +85,7 @@ typedef struct H5FD_core_t {
     DWORD           nFileIndexLow;
     DWORD           nFileIndexHigh;
     DWORD           dwVolumeSerialNumber;
-    
+
     HANDLE          hFile;      /* Native windows file handle */
 #endif /* H5_HAVE_WIN32_API */
     hbool_t dirty;                              /* changes not saved?       */
@@ -139,8 +143,8 @@ static herr_t H5FD__core_write(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, ha
             size_t size, const void *buf);
 static herr_t H5FD__core_flush(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
 static herr_t H5FD__core_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
-static herr_t H5FD_core_lock(H5FD_t *_file, hbool_t rw);
-static herr_t H5FD_core_unlock(H5FD_t *_file);
+static herr_t H5FD__core_lock(H5FD_t *_file, hbool_t rw);
+static herr_t H5FD__core_unlock(H5FD_t *_file);
 
 static const H5FD_class_t H5FD_core_g = {
     "core",                     /* name                 */
@@ -172,8 +176,8 @@ static const H5FD_class_t H5FD_core_g = {
     H5FD__core_write,           /* write                */
     H5FD__core_flush,           /* flush                */
     H5FD__core_truncate,        /* truncate             */
-    H5FD_core_lock,             /* lock                 */
-    H5FD_core_unlock,           /* unlock               */
+    H5FD__core_lock,            /* lock                 */
+    H5FD__core_unlock,          /* unlock               */
     H5FD_FLMAP_DICHOTOMY        /* fl_map               */
 };
 
@@ -337,9 +341,10 @@ H5FD__core_write_to_bstore(H5FD_core_t *file, haddr_t addr, size_t size)
     unsigned char  *ptr         = file->mem + addr;     /* mutable pointer into the
                                                          * buffer (can't change mem)
                                                          */
+    HDoff_t         offset      = (HDoff_t)addr;        /* Offset to write at */
     herr_t          ret_value   = SUCCEED;              /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
@@ -353,7 +358,6 @@ H5FD__core_write_to_bstore(H5FD_core_t *file, haddr_t addr, size_t size)
 
         h5_posix_io_t       bytes_in        = 0;    /* # of bytes to write  */
         h5_posix_io_ret_t   bytes_wrote     = -1;   /* # of bytes written   */
-        HDoff_t             offset          = (HDoff_t)addr;
 
         /* Trying to write more bytes than the return type can handle is
          * undefined behavior in POSIX.
@@ -366,7 +370,8 @@ H5FD__core_write_to_bstore(H5FD_core_t *file, haddr_t addr, size_t size)
         do {
 #ifdef H5_HAVE_PREADWRITE
             bytes_wrote = HDpwrite(file->fd, ptr, bytes_in, offset);
-            offset += bytes_wrote;
+            if(bytes_wrote > 0)
+                offset += bytes_wrote;
 #else
             bytes_wrote = HDwrite(file->fd, ptr, bytes_in);
 #endif /* H5_HAVE_PREADWRITE */
@@ -399,16 +404,26 @@ done:
  *
  * Purpose:     Initializes any interface-specific data or routines.
  *
- * Return:      Non-negative on success/Negative on failure 
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5FD__init_package(void)
 {
+    char    *lock_env_var   = NULL;     /* Environment variable pointer */
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
+
+    /* Check the use disabled file locks environment variable */
+    lock_env_var = HDgetenv("HDF5_USE_FILE_LOCKING");
+    if(lock_env_var && !HDstrcmp(lock_env_var, "BEST_EFFORT"))
+        ignore_disabled_file_locks_s = TRUE;    /* Override: Ignore disabled locks */
+    else if(lock_env_var && (!HDstrcmp(lock_env_var, "TRUE") || !HDstrcmp(lock_env_var, "1")))
+        ignore_disabled_file_locks_s = FALSE;   /* Override: Don't ignore disabled locks */
+    else
+        ignore_disabled_file_locks_s = FAIL;    /* Environment variable not set, or not set correctly */
 
     if(H5FD_core_init() < 0)
         HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, FAIL, "unable to initialize core VFD")
@@ -424,8 +439,8 @@ done:
  * Purpose:     Initialize this driver by registering the driver with the
  *              library.
  *
- * Return:      Success:    The driver ID for the core driver.
- *              Failure:    Negative.
+ * Return:      Success:    The driver ID for the core driver
+ *              Failure:    H5I_INVALID_HID
  *
  * Programmer:  Robb Matzke
  *              Thursday, July 29, 1999
@@ -437,7 +452,7 @@ H5FD_core_init(void)
 {
     hid_t ret_value = H5I_INVALID_HID;  /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_NOAPI(H5I_INVALID_HID)
 
     if(H5I_VFL != H5I_get_type(H5FD_CORE_g))
         H5FD_CORE_g = H5FD_register(&H5FD_core_g, sizeof(H5FD_class_t), FALSE);
@@ -649,9 +664,9 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
     if((file_image_info.buffer != NULL) && !(H5F_ACC_CREAT & flags)) {
         if(HDopen(name, o_flags, H5_POSIX_CREATE_MODE_RW) >= 0)
             HGOTO_ERROR(H5E_FILE, H5E_FILEEXISTS, NULL, "file already exists")
-        
+
         /* If backing store is requested, create and stat the file
-         * Note: We are forcing the O_CREAT flag here, even though this is 
+         * Note: We are forcing the O_CREAT flag here, even though this is
          * technically an open.
          */
         if(fa->backing_store) {
@@ -690,6 +705,16 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
     /* Save file image callbacks */
     file->fi_callbacks = file_image_info.callbacks;
 
+    /* Check the file locking flags in the fapl */
+    if(ignore_disabled_file_locks_s != FAIL)
+        /* The environment variable was set, so use that preferentially */
+        file->ignore_disabled_file_locks = ignore_disabled_file_locks_s;
+    else {
+        /* Use the value in the property list */
+        if(H5P_get(plist, H5F_ACS_IGNORE_DISABLED_FILE_LOCKS_NAME, &file->ignore_disabled_file_locks) < 0)
+            HGOTO_ERROR(H5E_VFL, H5E_CANTGET, NULL, "can't get ignore disabled file locks property")
+    }
+
     if(fd >= 0) {
         /* Retrieve information for determining uniqueness of file */
 #ifdef H5_HAVE_WIN32_API
@@ -741,21 +766,21 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
                         HGOTO_ERROR(H5E_FILE, H5E_CANTCOPY, NULL, "image_memcpy callback failed")
                 } /* end if */
                 else
-                    HDmemcpy(file->mem, file_image_info.buffer, size);
+                    H5MM_memcpy(file->mem, file_image_info.buffer, size);
             } /* end if */
             /* Read in existing data from the file if there is no image */
             else {
                 /* Read in existing data, being careful of interrupted system calls,
                  * partial results, and the end of the file.
                  */
-                
-                uint8_t *mem = file->mem; /* memory pointer for writes */
-                
+
+                uint8_t *mem = file->mem;       /* memory pointer for writes */
+                HDoff_t offset = (HDoff_t)0;    /* offset for reading */
+
                 while(size > 0) {
                     h5_posix_io_t       bytes_in        = 0;    /* # of bytes to read       */
                     h5_posix_io_ret_t   bytes_read      = -1;   /* # of bytes actually read */
-                    HDoff_t             offset          = (HDoff_t)0;
-                    
+
                     /* Trying to read more bytes than the return type can handle is
                      * undefined behavior in POSIX.
                      */
@@ -763,16 +788,17 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
                         bytes_in = H5_POSIX_MAX_IO_BYTES;
                     else
                         bytes_in = (h5_posix_io_t)size;
-                    
+
                     do {
 #ifdef H5_HAVE_PREADWRITE
                         bytes_read = HDpread(file->fd, mem, bytes_in, offset);
-                        offset += bytes_read;
+                        if(bytes_read > 0)
+                            offset += bytes_read;
 #else
                         bytes_read = HDread(file->fd, mem, bytes_in);
 #endif /* H5_HAVE_PREADWRITE */
                     } while(-1 == bytes_read && EINTR == errno);
-                    
+
                     if(-1 == bytes_read) { /* error */
                         int myerrno = errno;
                         time_t mytime = HDtime(NULL);
@@ -781,10 +807,10 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
 
                         HGOTO_ERROR(H5E_IO, H5E_READERROR, NULL, "file read failed: time = %s, filename = '%s', file descriptor = %d, errno = %d, error message = '%s', file->mem = %p, total read size = %llu, bytes this sub-read = %llu, bytes actually read = %llu, offset = %llu", HDctime(&mytime), file->name, file->fd, myerrno, HDstrerror(myerrno), file->mem, (unsigned long long)size, (unsigned long long)bytes_in, (unsigned long long)bytes_read, (unsigned long long)offset);
                     } /* end if */
-                    
+
                     HDassert(bytes_read >= 0);
                     HDassert((size_t)bytes_read <= size);
-                    
+
                     mem += bytes_read;
                     size -= (size_t)bytes_read;
                 } /* end while */
@@ -811,7 +837,7 @@ H5FD__core_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
          * on open (when not read-only).
          */
         /* Only use write tracking if the file is open for writing */
-        use_write_tracking = 
+        use_write_tracking =
             TRUE == write_tracking_flag         /* user asked for write tracking */
             && !(o_flags & O_RDONLY)            /* file is open for writing (i.e. not read-only) */
             && file->bstore_page_size != 0;     /* page size is not zero */
@@ -1200,7 +1226,7 @@ H5FD__core_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNU
         nbytes = MIN(size,(size_t)(file->eof-addr));
 #endif /* NDEBUG */
 
-        HDmemcpy(buf, file->mem + addr, nbytes);
+        H5MM_memcpy(buf, file->mem + addr, nbytes);
         size -= nbytes;
         addr += nbytes;
         buf = (char *)buf + nbytes;
@@ -1286,7 +1312,7 @@ H5FD__core_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UN
     }
 
     /* Write from BUF to memory */
-    HDmemcpy(file->mem + addr, buf, size);
+    H5MM_memcpy(file->mem + addr, buf, size);
 
     /* Mark memory buffer as modified */
     file->dirty = TRUE;
@@ -1365,24 +1391,24 @@ done:
  *              than the end-of-address.
  *
  *              Addendum -- 12/2/11
- *              For file images opened with the core file driver, it is 
+ *              For file images opened with the core file driver, it is
  *              necessary that we avoid reallocating the core file driver's
  *              buffer uneccessarily.
  *
  *              To this end, I have made the following functional changes
- *              to this function.  
+ *              to this function.
  *
- *              If we are closing, and there is no backing store, this 
+ *              If we are closing, and there is no backing store, this
  *              function becomes a no-op.
  *
  *              If we are closing, and there is backing store, we set the
- *              eof to equal the eoa, and truncate the backing store to 
+ *              eof to equal the eoa, and truncate the backing store to
  *              the new eof
  *
- *              If we are not closing, we realloc the buffer to size equal 
- *              to the smallest multiple of the allocation increment that 
- *              equals or exceeds the eoa and set the eof accordingly.  
- *              Note that we no longer truncate	the backing store to the 
+ *              If we are not closing, we realloc the buffer to size equal
+ *              to the smallest multiple of the allocation increment that
+ *              equals or exceeds the eoa and set the eof accordingly.
+ *              Note that we no longer truncate	the backing store to the
  *              new eof if applicable.
  *                                                                  -- JRM
  *
@@ -1479,7 +1505,7 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_core_lock
+ * Function:    H5FD__core_lock
  *
  * Purpose:     To place an advisory lock on a file.
  *		The lock type to apply depends on the parameter "rw":
@@ -1493,13 +1519,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_core_lock(H5FD_t *_file, hbool_t rw)
+H5FD__core_lock(H5FD_t *_file, hbool_t rw)
 {
     H5FD_core_t *file = (H5FD_core_t*)_file;    /* VFD file struct          */
     int lock_flags;                             /* file locking flags       */
     herr_t ret_value = SUCCEED;                 /* Return value             */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
@@ -1507,27 +1533,29 @@ H5FD_core_lock(H5FD_t *_file, hbool_t rw)
      * descriptor, this is a no-op.
      */
     if(file->fd >= 0) {
-
         /* Set exclusive or shared lock based on rw status */
         lock_flags = rw ? LOCK_EX : LOCK_SH;
 
         /* Place a non-blocking lock on the file */
         if(HDflock(file->fd, lock_flags | LOCK_NB) < 0) {
-            if(ENOSYS == errno)
-                HSYS_GOTO_ERROR(H5E_FILE, H5E_BADFILE, FAIL, "file locking disabled on this file system (use HDF5_USE_FILE_LOCKING environment variable to override)")
+            if(file->ignore_disabled_file_locks && ENOSYS == errno) {
+                /* When errno is set to ENOSYS, the file system does not support
+                 * locking, so ignore it.
+                 */
+                errno = 0;
+            }
             else
                 HSYS_GOTO_ERROR(H5E_FILE, H5E_BADFILE, FAIL, "unable to lock file")
         } /* end if */
-
     } /* end if */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_core_lock() */
+} /* end H5FD__core_lock() */
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_core_unlock
+ * Function:    H5FD__core_unlock
  *
  * Purpose:     To remove the existing lock on the file
  *
@@ -1538,27 +1566,28 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_core_unlock(H5FD_t *_file)
+H5FD__core_unlock(H5FD_t *_file)
 {
     H5FD_core_t *file = (H5FD_core_t*)_file;	/* VFD file struct */
     herr_t ret_value = SUCCEED;                 /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
-    if(file->fd >= 0) {
-
+    if(file->fd >= 0)
         if(HDflock(file->fd, LOCK_UN) < 0) {
-            if(ENOSYS == errno)
-                HSYS_GOTO_ERROR(H5E_FILE, H5E_BADFILE, FAIL, "file locking disabled on this file system (use HDF5_USE_FILE_LOCKING environment variable to override)")
+            if(file->ignore_disabled_file_locks && ENOSYS == errno) {
+                /* When errno is set to ENOSYS, the file system does not support
+                 * locking, so ignore it.
+                 */
+                errno = 0;
+            }
             else
                 HSYS_GOTO_ERROR(H5E_FILE, H5E_BADFILE, FAIL, "unable to unlock file")
-        } /* end if */
-
-    } /* end if */
+        }
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_core_unlock() */
+} /* end H5FD__core_unlock() */
 
