@@ -14,14 +14,12 @@
 /*-------------------------------------------------------------------------
  *
  * Created:	H5G.c
- *		Jul 18 1997
- *		Robb Matzke <matzke@llnl.gov>
  *
  * Purpose:	Symbol table functions.	 The functions that begin with
- *		`H5G_stab_' don't understand the naming system; they operate
+ *		'H5G_stab_' don't understand the naming system; they operate
  * 		on a single symbol table at a time.
  *
- *		The functions that begin with `H5G_node_' operate on the leaf
+ *		The functions that begin with 'H5G_node_' operate on the leaf
  *		nodes of a symbol table B-tree.  They should be defined in
  *		the H5Gnode.c file.
  *
@@ -42,11 +40,11 @@
  *              +--------------+----------- +--------------------------------+
  * 		| Location ID  | Name       | Meaning                        |
  *              +--------------+------------+--------------------------------+
- * 		| File ID      | "/foo/bar" | Find `foo' within `bar' within |
+ * 		| File ID      | "/foo/bar" | Find 'foo' within 'bar' within |
  *		|              |            | the root group of the specified|
  *		|              |            | file.                          |
  *              +--------------+------------+--------------------------------+
- * 		| File ID      | "foo/bar"  | Find `foo' within `bar' within |
+ * 		| File ID      | "foo/bar"  | Find 'foo' within 'bar' within |
  *		|              |            | the root group of the specified|
  *		|              |            | file.                          |
  *              +--------------+------------+--------------------------------+
@@ -56,11 +54,11 @@
  * 		| File ID      | "."        | The root group of the specified|
  *		|              |            | the specified file.            |
  *              +--------------+------------+--------------------------------+
- * 		| Group ID     | "/foo/bar" | Find `foo' within `bar' within |
+ * 		| Group ID     | "/foo/bar" | Find 'foo' within 'bar' within |
  *		|              |            | the root group of the file     |
  *		|              |            | containing the specified group.|
  *              +--------------+------------+--------------------------------+
- * 		| Group ID     | "foo/bar"  | File `foo' within `bar' within |
+ * 		| Group ID     | "foo/bar"  | File 'foo' within 'bar' within |
  *		|              |            | the specified group.           |
  *              +--------------+------------+--------------------------------+
  * 		| Group ID     | "/"        | The root group of the file     |
@@ -83,13 +81,13 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5ACprivate.h"	/* Metadata cache			*/
-#include "H5CXprivate.h"        /* API Contexts                         */
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Gpkg.h"		/* Groups		  		*/
-#include "H5Iprivate.h"		/* IDs			  		*/
-#include "H5Pprivate.h"         /* Property lists                       */
+#include "H5private.h"          /* Generic Functions                        */
+#include "H5ACprivate.h"        /* Metadata cache                           */
+#include "H5CXprivate.h"        /* API Contexts                             */
+#include "H5Eprivate.h"         /* Error handling                           */
+#include "H5Gpkg.h"             /* Groups                                   */
+#include "H5Iprivate.h"         /* IDs                                      */
+#include "H5Pprivate.h"         /* Property lists                           */
 
 
 /****************/
@@ -131,10 +129,10 @@ hbool_t H5_PKG_INIT_VAR = FALSE;
 
 /* Group ID class */
 static const H5I_class_t H5I_GROUP_CLS[1] = {{
-    H5I_GROUP,			/* ID class value */
-    0,				/* Class flags */
-    0,				/* # of reserved IDs for class */
-    (H5I_free_t)H5G__close_cb	/* Callback routine for closing objects of this class */
+    H5I_GROUP,                      /* ID class value */
+    0,                              /* Class flags */
+    0,                              /* # of reserved IDs for class */
+    (H5I_free_t)H5G__close_cb       /* Callback routine for closing objects of this class */
 }};
 
 /* Flag indicating "top" of interface has been initialized */
@@ -258,9 +256,9 @@ H5G_term_package(void)
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gcreate2
+ * Function:    H5Gcreate2
  *
- * Purpose:	Creates a new group relative to LOC_ID, giving it the
+ * Purpose:     Creates a new group relative to LOC_ID, giving it the
  *              specified creation property list GCPL_ID and access
  *              property list GAPL_ID.  The link to the new group is
  *              created with the LCPL_ID.
@@ -272,14 +270,11 @@ H5G_term_package(void)
  *                  hid_t gcpl_id;	  IN: Property list for group creation
  *                  hid_t gapl_id;	  IN: Property list for group access
  *
- * Return:	Success:	The object ID of a new, empty group open for
- *				writing.  Call H5Gclose() when finished with
- *				the group.
+ * Return:      Success:    The object ID of a new, empty group open for
+ *                          writing.  Call H5Gclose() when finished with
+ *                          the group.
  *
- *		Failure:	H5I_INVALID_HID
- *
- * Programmer:  Quincey Koziol
- *	        April 5, 2007
+ *              Failure:    H5I_INVALID_HID
  *
  *-------------------------------------------------------------------------
  */
@@ -314,6 +309,9 @@ H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id,
         if(TRUE != H5P_isa_class(gcpl_id, H5P_GROUP_CREATE))
             HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not group create property list")
 
+    /* Set the LCPL for the API context */
+    H5CX_set_lcpl(lcpl_id);
+
     /* Verify access property list and set up collective metadata if appropriate */
     if(H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, TRUE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, H5I_INVALID_HID, "can't set access property list info")
@@ -334,9 +332,9 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gcreate_anon
+ * Function:    H5Gcreate_anon
  *
- * Purpose:	Creates a new group relative to LOC_ID, giving it the
+ * Purpose:     Creates a new group relative to LOC_ID, giving it the
  *              specified creation property list GCPL_ID and access
  *              property list GAPL_ID.
  *
@@ -352,19 +350,16 @@ done:
  *                  hid_t gcpl_id;	  IN: Property list for group creation
  *                  hid_t gapl_id;	  IN: Property list for group access
  *
- * Example:	To create missing groups "A" and "B01" along the given path "/A/B01/grp"
+ * Example:     To create missing groups "A" and "B01" along the given path "/A/B01/grp"
  *              hid_t create_id = H5Pcreate(H5P_GROUP_CREATE);
  *              int   status = H5Pset_create_intermediate_group(create_id, TRUE);
  *              hid_t gid = H5Gcreate_anon(file_id, "/A/B01/grp", create_id, H5P_DEFAULT);
  *
- * Return:	Success:	The object ID of a new, empty group open for
- *				writing.  Call H5Gclose() when finished with
- *				the group.
+ * Return:      Success:    The object ID of a new, empty group open for
+ *                          writing. Call H5Gclose() when finished with
+ *                          the group.
  *
- *		Failure:	H5I_INVALID_HID
- *
- * Programmer:  Peter Cao
- *	        May 08, 2005
+ *              Failure:    H5I_INVALID_HID
  *
  *-------------------------------------------------------------------------
  */
@@ -400,10 +395,10 @@ H5Gcreate_anon(hid_t loc_id, hid_t gcpl_id, hid_t gapl_id)
     HDmemset(&gcrt_info.cache, 0, sizeof(gcrt_info.cache));
 
     /* Create the new group & get its ID */
-    if(NULL == (grp = H5G__create_anon(loc.oloc->file, &gcrt_info)))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, H5I_INVALID_HID, "unable to create group")
+    if(NULL == (grp = H5G__create(loc.oloc->file, &gcrt_info)))
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, H5I_INVALID_HID, "unable to create group")
     if((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
-	HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
+        HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
 
 done:
     /* Release the group's object header, if it was created */
@@ -429,19 +424,17 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gopen2
+ * Function:    H5Gopen2
  *
- * Purpose:	Opens an existing group for modification.  When finished,
- *		call H5Gclose() to close it and release resources.
+ * Purpose:     Opens an existing group for modification.  When finished,
+ *              call H5Gclose() to close it and release resources.
  *
  *              This function allows the user the pass in a Group Access
  *              Property List, which H5Gopen1() does not.
  *
- * Return:	Success:	Object ID of the group.
- *		Failure:	H5I_INVALID_HID
+ * Return:      Success:    Object ID of the group
  *
- * Programmer:	James Laird
- *		Thursday, July 27, 2006
+ *              Failure:    H5I_INVALID_HID
  *
  *-------------------------------------------------------------------------
  */
@@ -483,18 +476,15 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gget_create_plist
+ * Function:    H5Gget_create_plist
  *
- * Purpose:	Returns a copy of the group creation property list.
+ * Purpose:     Returns a copy of the group creation property list.
  *
- * Return:	Success:	ID for a copy of the group creation
- *				property list.  The property list ID should be
- *				released by calling H5Pclose().
+ * Return:      Success:    ID for a copy of the group creation
+ *                          property list.  The property list ID should be
+ *                          released by calling H5Pclose().
  *
- *		Failure:	H5I_INVALID_HID
- *
- * Programmer:	Quincey Koziol
- *		Tuesday, October 25, 2005
+ *              Failure:    H5I_INVALID_HID
  *
  *-------------------------------------------------------------------------
  */
@@ -509,10 +499,11 @@ H5Gget_create_plist(hid_t group_id)
 
     /* Check args */
     if(NULL == (group = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a group")
 
-    if((ret_value = H5G__get_create_plist(group)) < 0)
-	HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5I_INVALID_HID, "can't get group's creation property list")
+    /* Retrieve the GCPL */
+    if((ret_value = H5G_get_create_plist(group)) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5I_INVALID_HID, "can't get group's creation property list")
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -520,15 +511,11 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gget_info
+ * Function:    H5Gget_info
  *
- * Purpose:	Retrieve information about a group.
+ * Purpose:     Retrieve information about a group.
  *
- * Return:	Success:	Non-negative
- *		Failure:	Negative
- *
- * Programmer:	Quincey Koziol
- *		November 27 2006
+ * Return:      SUCCEED/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -554,7 +541,7 @@ H5Gget_info(hid_t grp_id, H5G_info_t *grp_info)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
 
     /* Retrieve the group's information */
-    if(H5G__get_info(&loc, grp_info/*out*/) < 0)
+    if(H5G__obj_info(loc.oloc, grp_info) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't retrieve group info")
 
 done:
@@ -563,15 +550,12 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gget_info_by_name
+ * Function:    H5Gget_info_by_name
  *
- * Purpose:	Retrieve information about a group.
+ * Purpose:     Retrieve information about a group, where the group is
+ *              identified by name instead of ID.
  *
- * Return:	Success:	Non-negative
- *		Failure:	Negative
- *
- * Programmer:	Quincey Koziol
- *		November 27 2006
+ * Return:      SUCCEED/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -607,16 +591,12 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gget_info_by_idx
+ * Function:    H5Gget_info_by_idx
  *
- * Purpose:	Retrieve information about a group, according to the order
+ * Purpose:     Retrieve information about a group, according to the order
  *              of an index.
  *
- * Return:	Success:	Non-negative
- *		Failure:	Negative
- *
- * Programmer:	Quincey Koziol
- *		November 27 2006
+ * Return:      SUCCEED/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -657,15 +637,12 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Gclose
+ * Function:    H5Gclose
  *
- * Purpose:	Closes the specified group.  The group ID will no longer be
- *		valid for accessing the group.
+ * Purpose:     Closes the specified group. The group ID will no longer be
+ *              valid for accessing the group.
  *
- * Return:	Non-negative on success/Negative on failure
- *
- * Programmer:	Robb Matzke
- *		Wednesday, December 31, 1997
+ * Return:      SUCCEED/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -678,11 +655,10 @@ H5Gclose(hid_t group_id)
     H5TRACE1("e", "i", group_id);
 
     /* Check args */
-    if(NULL == H5I_object_verify(group_id,H5I_GROUP))
+    if(NULL == H5I_object_verify(group_id, H5I_GROUP))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
 
-    /*
-     * Decrement the counter on the group atom.	 It will be freed if the count
+    /* Decrement the counter on the group atom. It will be freed if the count
      * reaches zero.
      */
     if(H5I_dec_app_ref(group_id) < 0)
@@ -713,7 +689,7 @@ H5Gflush(hid_t group_id)
 
     FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "i", group_id);
-    
+
     /* Check args */
     if(NULL == (grp = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
@@ -722,9 +698,9 @@ H5Gflush(hid_t group_id)
     if(H5CX_set_loc(group_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set collective metadata read info")
 
-    /* Flush group's metadata to file */
-    if(H5G__flush(grp, group_id) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTFLUSH, FAIL, "unable to flush group")
+    /* Flush metadata to file */
+    if(H5O_flush_common(&grp->oloc, group_id) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTFLUSH, FAIL, "unable to flush group and object flush callback")
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -748,7 +724,7 @@ H5Grefresh(hid_t group_id)
 {
     H5G_t *grp;                 /* Group for this operation */
     herr_t ret_value = SUCCEED; /* Return value */
-    
+
     FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "i", group_id);
 
@@ -761,7 +737,7 @@ H5Grefresh(hid_t group_id)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set collective metadata read info")
 
     /* Call private function to refresh group object */
-    if((H5G__refresh(grp, group_id)) < 0)
+    if((H5O_refresh_metadata(group_id, grp->oloc)) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTLOAD, FAIL, "unable to refresh group")
 
 done:
