@@ -15,7 +15,7 @@
  *
  * Created:		H5HFman.c
  *			Feb 24 2006
- *			Quincey Koziol <koziol@ncsa.uiuc.edu>
+ *			Quincey Koziol
  *
  * Purpose:		"Managed" object routines for fractal heaps.
  *
@@ -97,7 +97,6 @@ static herr_t H5HF__man_op_real(H5HF_hdr_t *hdr, const uint8_t *id,
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Mar 13 2006
  *
  *-------------------------------------------------------------------------
@@ -140,6 +139,7 @@ H5HF__man_insert(H5HF_hdr_t *hdr, size_t obj_size, const void *obj, void *_id)
     /* Check for row section */
     if(sec_node->sect_info.type == H5HF_FSPACE_SECT_FIRST_ROW ||
             sec_node->sect_info.type == H5HF_FSPACE_SECT_NORMAL_ROW) {
+
         /* Allocate 'single' selection out of 'row' selection */
         if(H5HF__man_iblock_alloc_row(hdr, &sec_node) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't break up row section")
@@ -182,7 +182,7 @@ H5HF__man_insert(H5HF_hdr_t *hdr, size_t obj_size, const void *obj, void *_id)
         p = dblock->blk + blk_off;
 
         /* Copy the object's data into the heap */
-        HDmemcpy(p, obj, obj_size);
+        H5MM_memcpy(p, obj, obj_size);
         p += obj_size;
 
         /* Sanity check */
@@ -220,7 +220,7 @@ done:
  *
  * Return:      SUCCEED (Can't fail)
  *
- * Programmer:  Dana Robinson (derobins@hdfgroup.org)
+ * Programmer:  Dana Robinson
  *              August 2012
  *
  *-------------------------------------------------------------------------
@@ -237,7 +237,7 @@ H5HF_man_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
     HDassert(hdr);
     HDassert(id);
     HDassert(obj_len_p);
-    
+
     /* Skip over the flag byte */
     id++;
 
@@ -259,7 +259,6 @@ H5HF_man_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
  * Return:      SUCCEED (Can't fail)
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Aug 20 2015
  *
  *-------------------------------------------------------------------------
@@ -275,7 +274,7 @@ H5HF__man_get_obj_off(const H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off
     HDassert(hdr);
     HDassert(id);
     HDassert(obj_off_p);
-    
+
     /* Skip over the flag byte */
     id++;
 
@@ -295,7 +294,6 @@ H5HF__man_get_obj_off(const H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Mar 17 2006
  *
  *-------------------------------------------------------------------------
@@ -306,8 +304,8 @@ H5HF__man_op_real(H5HF_hdr_t *hdr, const uint8_t *id,
 {
     H5HF_direct_t *dblock = NULL;       /* Pointer to direct block to query */
     unsigned dblock_access_flags;       /* Access method for direct block */
-                                        /* must equal either 
-                                         * H5AC__NO_FLAGS_SET or 
+                                        /* must equal either
+                                         * H5AC__NO_FLAGS_SET or
                                          * H5AC__READ_ONLY_FLAG
                                          */
     haddr_t dblock_addr;                /* Direct block address */
@@ -444,7 +442,6 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Mar 17 2006
  *
  *-------------------------------------------------------------------------
@@ -480,7 +477,6 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Dec 18 2006
  *
  *-------------------------------------------------------------------------
@@ -517,7 +513,6 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Sept 11 2006
  *
  *-------------------------------------------------------------------------
@@ -553,7 +548,6 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		May 15 2006
  *
  *-------------------------------------------------------------------------
