@@ -15,7 +15,7 @@
  *
  * Created:		H5Omessage.c
  *			Dec  3 2006
- *			Quincey Koziol <koziol@hdfgroup.org>
+ *			Quincey Koziol
  *
  * Purpose:		Object header message routines.
  *
@@ -105,7 +105,6 @@ static herr_t H5O__copy_mesg(H5F_t *f, H5O_t *oh, size_t idx,
  *		Failure:	Negative
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Dec  1 2006
  *
  *-------------------------------------------------------------------------
@@ -127,11 +126,11 @@ H5O_msg_create(const H5O_loc_t *loc, unsigned type_id, unsigned mesg_flags,
 
     /* Pin the object header */
     if(NULL == (oh = H5O_pin(loc)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
 
     /* Go append message to object header */
     if(H5O_msg_append_oh(loc->file, oh, type_id, mesg_flags, update_flags, mesg) < 0)
-	HGOTO_ERROR(H5E_OHDR, H5E_WRITEERROR, FAIL, "unable to append to object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_WRITEERROR, FAIL, "unable to append to object header")
 
 done:
     if(oh && H5O_unpin(oh) < 0)
@@ -153,7 +152,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Dec 31 2002
  *
  *-------------------------------------------------------------------------
@@ -196,7 +194,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Dec  8 2006
  *
  *-------------------------------------------------------------------------
@@ -248,7 +245,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug  6 1997
  *
  *-------------------------------------------------------------------------
@@ -276,7 +272,7 @@ H5O_msg_write(const H5O_loc_t *loc, unsigned type_id, unsigned mesg_flags,
 
     /* Pin the object header */
     if(NULL == (oh = H5O_pin(loc)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
 
     /* Call the "real" modify routine */
     if(H5O__msg_write_real(loc->file, oh, type, mesg_flags, update_flags, mesg) < 0)
@@ -304,7 +300,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Dec  6 2007
  *
  *-------------------------------------------------------------------------
@@ -352,7 +347,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug  6 1997
  *
  *-------------------------------------------------------------------------
@@ -384,7 +378,7 @@ H5O__msg_write_real(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type,
 
     /* Check for modifying a constant message */
     if(!(update_flags & H5O_UPDATE_FORCE) && (idx_msg->flags & H5O_MSG_FLAG_CONSTANT))
-	HGOTO_ERROR(H5E_OHDR, H5E_WRITEERROR, FAIL, "unable to modify constant message")
+        HGOTO_ERROR(H5E_OHDR, H5E_WRITEERROR, FAIL, "unable to modify constant message")
     /* This message is shared, but it's being modified. */
     else if((idx_msg->flags & H5O_MSG_FLAG_SHARED) || (idx_msg->flags & H5O_MSG_FLAG_SHAREABLE)) {
         htri_t status;              /* Status of "try share" call */
@@ -453,7 +447,6 @@ done:
  *		Failure:	NULL
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug  6 1997
  *
  *-------------------------------------------------------------------------
@@ -474,15 +467,15 @@ H5O_msg_read(const H5O_loc_t *loc, unsigned type_id, void *mesg)
 
     /* Get the object header */
     if(NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, NULL, "unable to protect object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, NULL, "unable to protect object header")
 
     /* Call the "real" read routine */
     if(NULL == (ret_value = H5O_msg_read_oh(loc->file, oh, type_id, mesg)))
-	HGOTO_ERROR(H5E_OHDR, H5E_READERROR, NULL, "unable to read object header message")
+        HGOTO_ERROR(H5E_OHDR, H5E_READERROR, NULL, "unable to read object header message")
 
 done:
     if(oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-	HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, NULL, "unable to release object header")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, NULL, "unable to release object header")
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5O_msg_read() */
@@ -506,7 +499,6 @@ done:
  *		Failure:	NULL
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug  6 1997
  *
  *-------------------------------------------------------------------------
@@ -563,7 +555,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug 12 1997
  *
  *-------------------------------------------------------------------------
@@ -600,7 +591,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug 12 1997
  *
  *-------------------------------------------------------------------------
@@ -616,12 +606,12 @@ H5O__msg_reset_real(const H5O_msg_class_t *type, void *native)
     HDassert(type);
 
     if(native) {
-	if(type->reset) {
-	    if((type->reset)(native) < 0)
-		HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "reset method failed")
-	} /* end if */
+        if(type->reset) {
+            if((type->reset)(native) < 0)
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "reset method failed")
+        } /* end if */
         else
-	    HDmemset(native, 0, type->native_size);
+            HDmemset(native, 0, type->native_size);
     } /* end if */
 
 done:
@@ -798,7 +788,7 @@ H5O_msg_count(const H5O_loc_t *loc, unsigned type_id)
 
     /* Load the object header */
     if(NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header")
 
     /* Count the messages of the correct type */
     msg_count = H5O_msg_count_real(oh, type);
@@ -806,7 +796,7 @@ H5O_msg_count(const H5O_loc_t *loc, unsigned type_id)
 
 done:
     if(oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-	HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_msg_count() */
@@ -841,7 +831,7 @@ H5O_msg_count_real(const H5O_t *oh, const H5O_msg_class_t *type)
 
     /* Loop over all messages, counting the ones of the type looked for */
     for(u = ret_value = 0; u < oh->nmesgs; u++)
-	if(oh->mesg[u].type == type)
+        if(oh->mesg[u].type == type)
             ret_value++;
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -951,7 +941,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug 28 1997
  *
  *-------------------------------------------------------------------------
@@ -976,11 +965,11 @@ H5O_msg_remove(const H5O_loc_t *loc, unsigned type_id, int sequence, hbool_t adj
 
     /* Pin the object header */
     if(NULL == (oh = H5O_pin(loc)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
 
     /* Call the "real" remove routine */
     if((ret_value = H5O__msg_remove_real(loc->file, oh, type, sequence, NULL, NULL, adj_link)) < 0)
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "unable to remove object header message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "unable to remove object header message")
 
 done:
     if(oh && H5O_unpin(oh) < 0)
@@ -1002,7 +991,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Sep  6 2005
  *
  *-------------------------------------------------------------------------
@@ -1028,11 +1016,11 @@ H5O_msg_remove_op(const H5O_loc_t *loc, unsigned type_id, int sequence,
 
     /* Pin the object header */
     if(NULL == (oh = H5O_pin(loc)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPIN, FAIL, "unable to pin object header")
 
     /* Call the "real" remove routine */
     if((ret_value = H5O__msg_remove_real(loc->file, oh, type, sequence, op, op_data, adj_link)) < 0)
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "unable to remove object header message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "unable to remove object header message")
 
 done:
     if(oh && H5O_unpin(oh) < 0)
@@ -1052,7 +1040,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Sep  6 2005
  *
  *-------------------------------------------------------------------------
@@ -1118,7 +1105,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Robb Matzke
- *		matzke@llnl.gov
  *		Aug 28 1997
  *
  *-------------------------------------------------------------------------
@@ -1175,7 +1161,6 @@ done:
  *      object headers were processed.
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Nov 19 2004
  *
  * Description:
@@ -1241,7 +1226,6 @@ done:
  *      object headers were processed.
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Sep  6 2005
  *
  * Description:
@@ -1316,7 +1300,7 @@ done:
          */
 	if(oh_modified & H5O_MODIFY_CONDENSE)
 	    if(H5O_condense_header(f, oh) < 0)
-		HDONE_ERROR(H5E_OHDR, H5E_CANTPACK, FAIL, "can't pack object header")
+            HDONE_ERROR(H5E_OHDR, H5E_CANTPACK, FAIL, "can't pack object header")
 
         /* Mark object header as changed */
         if(H5O_touch_oh(f, oh, FALSE) < 0)
@@ -1340,7 +1324,6 @@ done:
  * Return:	Size of message on success, 0 on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Feb 13 2003
  *
  *-------------------------------------------------------------------------
@@ -1383,7 +1366,6 @@ done:
  * Return:	Size of message on success, 0 on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Sep  6 2005
  *
  *-------------------------------------------------------------------------
@@ -1447,7 +1429,6 @@ done:
  * Return:	Size of message on success, 0 on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Mar  7 2007
  *
  *-------------------------------------------------------------------------
@@ -1584,7 +1565,6 @@ H5O_msg_can_share_in_ohdr(unsigned type_id)
  *              Object is not shared:    FALSE
  *
  * Programmer:  James Laird
- *              jlaird@ncsa.uiuc.edu
  *              April 5 2006
  *
  *-------------------------------------------------------------------------
@@ -1598,16 +1578,23 @@ H5O_msg_is_shared(unsigned type_id, const void *mesg)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check args */
-    HDassert(type_id < NELMTS(H5O_msg_class_g));
-    type = H5O_msg_class_g[type_id];    /* map the type ID to the actual type object */
-    HDassert(type);
-    HDassert(mesg);
-
-    /* If messages in a class aren't sharable, then obviously this message isn't shared! :-) */
-    if(type->share_flags & H5O_SHARE_IS_SHARABLE)
-        ret_value = H5O_IS_STORED_SHARED(((const H5O_shared_t *)mesg)->type);
-    else
+#ifdef H5O_ENABLE_BOGUS
+    if(type_id >= NELMTS(H5O_msg_class_g))
         ret_value = FALSE;
+    else
+#endif /* H5O_ENABLE_BOGUS */
+    {
+        HDassert(type_id < NELMTS(H5O_msg_class_g));
+        type = H5O_msg_class_g[type_id];    /* map the type ID to the actual type object */
+        HDassert(type);
+        HDassert(mesg);
+
+        /* If messages in a class aren't sharable, then obviously this message isn't shared! :-) */
+        if(type->share_flags & H5O_SHARE_IS_SHARABLE)
+            ret_value = H5O_IS_STORED_SHARED(((const H5O_shared_t *)mesg)->type);
+        else
+            ret_value = FALSE;
+    } /* end block/else */
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_msg_is_shared() */
@@ -1622,7 +1609,6 @@ H5O_msg_is_shared(unsigned type_id, const void *mesg)
  *		Failure:	Negative
  *
  * Programmer:	James Laird
- *		jlaird@hdfgroup.org
  *		November 1 2006
  *
  *-------------------------------------------------------------------------
@@ -1673,13 +1659,12 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	James Laird
- *		jlaird@hdfgroup.org
  *		Oct 17 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5O_msg_reset_share(unsigned type_id, void *mesg)
+H5O_msg_reset_share(unsigned H5_ATTR_NDEBUG_UNUSED type_id, void *mesg)
 {
     const H5O_msg_class_t *type;        /* Actual H5O class type for the ID */
 
@@ -1752,7 +1737,6 @@ done:
  *		Failure:	Negative
  *
  * Programmer:	Raymond Lu
- *		slu@ncsa.uiuc.edu
  *		July 13, 2004
  *
  *-------------------------------------------------------------------------
@@ -1792,14 +1776,8 @@ done:
  *		Failure:	NULL
  *
  * Programmer:	Raymond Lu
- *		slu@ncsa.uiuc.edu
  *		July 14, 2004
  *
- * Modifications: Neil Fortner
- *              Feb 4 2009
- *              Added open_oh parameter.  This parameter is optional and
- *              contains this message's protected object header
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1973,7 +1951,7 @@ H5O__copy_mesg(H5F_t *f, H5O_t *oh, size_t idx, const H5O_msg_class_t *type,
 
     /* Protect chunk */
     if(NULL == (chk_proxy = H5O__chunk_protect(f, oh, idx_msg->chunkno)))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header chunk")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header chunk")
 
     /* Reset existing native information for the header's message */
     H5O__msg_reset_real(type, idx_msg->native);
@@ -1991,7 +1969,7 @@ H5O__copy_mesg(H5F_t *f, H5O_t *oh, size_t idx, const H5O_msg_class_t *type,
 
     /* Release chunk */
     if(H5O__chunk_unprotect(f, chk_proxy, chk_dirtied) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header chunk")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header chunk")
     chk_proxy = NULL;
 
     /* Update the modification time, if requested */
@@ -2063,7 +2041,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		September 26 2003
  *
  *-------------------------------------------------------------------------
@@ -2103,7 +2080,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		May 14 2007
  *
  *-------------------------------------------------------------------------
@@ -2204,7 +2180,6 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@ncsa.uiuc.edu
  *		Nov 21 2005
  *
  *-------------------------------------------------------------------------
