@@ -51,8 +51,9 @@
 /********************/
 /* Local Prototypes */
 /********************/
-static herr_t H5T_pack(const H5T_t *dt);
-static htri_t H5T_is_packed(const H5T_t *dt);
+static herr_t H5T__pack(const H5T_t *dt);
+static htri_t H5T__is_packed(const H5T_t *dt);
+static H5T_t *H5T__reopen_member_type(const H5T_t *dt, unsigned membno);
 
 
 /*********************/
@@ -92,8 +93,6 @@ static htri_t H5T_is_packed(const H5T_t *dt);
  * Programmer:	Robb Matzke
  *		Wednesday, January  7, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 size_t
@@ -162,8 +161,6 @@ H5T_get_member_offset(const H5T_t *dt, unsigned membno)
  * Programmer:	Quincey Koziol
  *		Thursday, November  9, 2000
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 H5T_class_t
@@ -226,7 +223,7 @@ H5Tget_member_type(hid_t type_id, unsigned membno)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid member number")
 
     /* Retrieve the datatype for the member */
-    if(NULL == (memb_dt = H5T_get_member_type(dt, membno, H5T_COPY_REOPEN)))
+    if(NULL == (memb_dt = H5T__reopen_member_type(dt, membno)))
         HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, H5I_INVALID_HID, "unable to retrieve member type")
 
     /* Get an ID for the datatype */
@@ -245,8 +242,7 @@ done:
 /*-------------------------------------------------------------------------
  * Function:	H5T_get_member_type
  *
- * Purpose:	Private function for H5Tget_member_type.  Returns the data
- *              type of the specified member.
+ * Purpose:     Returns a copy of the data type of the specified member.
  *
  * Return:	Success:	A copy of the member datatype;
  *				modifying the returned datatype does not
@@ -260,23 +256,61 @@ done:
  *-------------------------------------------------------------------------
  */
 H5T_t *
-H5T_get_member_type(const H5T_t *dt, unsigned membno, H5T_copy_t method)
+H5T_get_member_type(const H5T_t *dt, unsigned membno)
 {
     H5T_t	*ret_value = NULL;      /* Return value */
 
     FUNC_ENTER_NOAPI(NULL)
 
+    /* Sanity checks */
     HDassert(dt);
     HDassert(membno < dt->shared->u.compnd.nmembs);
 
-    /* Copy datatype into an atom */
-    if(NULL == (ret_value = H5T_copy(dt->shared->u.compnd.memb[membno].type, method)))
-	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, NULL, "unable to copy member datatype")
+    /* Copy datatype */
+    if(NULL == (ret_value = H5T_copy(dt->shared->u.compnd.memb[membno].type, H5T_COPY_TRANSIENT)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to copy member datatype")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5T_get_member_type() */
 
+
+/*-------------------------------------------------------------------------
+ * Function:	H5T__reopen_member_type
+ *
+ * Purpose:	Private function for H5Tget_member_type.  Returns a re-opened
+ *              copy of the data type of the specified member.
+ *
+ * Return:	Success:	A copy of the member datatype;
+ *				modifying the returned datatype does not
+ *				modify the member type.
+ *
+ *		Failure:        NULL
+ *
+ * Programmer:	David Young
+ *	        January 18, 2020
+ *
+ *-------------------------------------------------------------------------
+ */
+static H5T_t *
+H5T__reopen_member_type(const H5T_t *dt, unsigned membno)
+{
+    H5T_t	*ret_value = NULL;      /* Return value */
+
+    FUNC_ENTER_STATIC
+
+    /* Sanity checks */
+    HDassert(dt);
+    HDassert(membno < dt->shared->u.compnd.nmembs);
+
+    /* Copy datatype, possibly re-opening it */
+    if(NULL == (ret_value = H5T_copy_reopen(dt->shared->u.compnd.memb[membno].type)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to reopen member datatype")
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5T__reopen_member_type() */
+
 
 /*-------------------------------------------------------------------------
  * Function:	H5T__get_member_size
@@ -323,8 +357,6 @@ H5T__get_member_size(const H5T_t *dt, unsigned membno)
  * Programmer:	Robb Matzke
  *		Monday, December  8, 1997
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -369,8 +401,6 @@ done:
  * Programmer:	Robb Matzke
  *		Wednesday, January  7, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -387,7 +417,7 @@ H5Tpack(hid_t type_id)
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype")
 
     /* Pack */
-    if(H5T_pack(dt) < 0)
+    if(H5T__pack(dt) < 0)
 	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack compound datatype")
 
 done:
@@ -493,7 +523,7 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5T_pack
+ * Function:	H5T__pack
  *
  * Purpose:	Recursively packs a compound datatype by removing padding
  *		bytes. This is done in place (that is, destructively).
@@ -506,17 +536,17 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5T_pack(const H5T_t *dt)
+H5T__pack(const H5T_t *dt)
 {
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(dt);
 
     if(H5T_detect_class(dt, H5T_COMPOUND, FALSE) > 0) {
         /* If datatype has been packed, skip packing it and indicate success */
-        if(TRUE == H5T_is_packed(dt))
+        if(TRUE == H5T__is_packed(dt))
             HGOTO_DONE(SUCCEED)
 
         /* Check for packing unmodifiable datatype */
@@ -524,7 +554,7 @@ H5T_pack(const H5T_t *dt)
             HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "datatype is read-only")
 
         if(dt->shared->parent) {
-            if (H5T_pack(dt->shared->parent) < 0)
+            if(H5T__pack(dt->shared->parent) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack parent of datatype")
 
             /* Adjust size of datatype appropriately */
@@ -539,7 +569,7 @@ H5T_pack(const H5T_t *dt)
 
             /* Recursively pack the members */
             for(i = 0; i < dt->shared->u.compnd.nmembs; i++) {
-                if(H5T_pack(dt->shared->u.compnd.memb[i].type) < 0)
+                if(H5T__pack(dt->shared->u.compnd.memb[i].type) < 0)
                     HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack part of a compound datatype")
 
                 /* Update the member size */
@@ -564,11 +594,11 @@ H5T_pack(const H5T_t *dt)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5T_pack() */
+} /* end H5T__pack() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5T_is_packed
+ * Function:	H5T__is_packed
  *
  * Purpose:	Checks whether a datatype which is compound (or has compound
  *              components) is packed.
@@ -578,16 +608,14 @@ done:
  * Programmer:	Quincey Koziol
  *		Thursday, September 11, 2003
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
-H5T_is_packed(const H5T_t *dt)
+H5T__is_packed(const H5T_t *dt)
 {
     htri_t      ret_value = TRUE;       /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(dt);
 
@@ -596,12 +624,11 @@ H5T_is_packed(const H5T_t *dt)
         dt = dt->shared->parent;
 
     /* If this is a compound datatype, check if it is packed */
-    if(dt->shared->type == H5T_COMPOUND) {
+    if(dt->shared->type == H5T_COMPOUND)
         ret_value = (htri_t)(dt->shared->u.compnd.packed);
-    } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5T_is_packed() */
+} /* end H5T__is_packed() */
 
 
 /*-------------------------------------------------------------------------
@@ -617,8 +644,6 @@ H5T_is_packed(const H5T_t *dt)
  * Programmer:	Neil Fortner
  *		Monday, October 19, 2009
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -638,7 +663,7 @@ H5T__update_packed(const H5T_t *dt)
 
         /* Now check if all members are packed */
         for(i = 0; i < dt->shared->u.compnd.nmembs; i++)
-            if(!H5T_is_packed(dt->shared->u.compnd.memb[i].type)) {
+            if(!H5T__is_packed(dt->shared->u.compnd.memb[i].type)) {
                 dt->shared->u.compnd.packed = FALSE;
                 break;
             } /* end if */
