@@ -43,9 +43,17 @@ static const char *FileHeader = "\n\
  */
 #undef NDEBUG
 #include "H5private.h"
+/* Do NOT use HDfprintf in this file as it is not linked with the library,
+ * which contains the H5system.c file in which the function is defined.
+ */
 #include "H5Tpublic.h"
 #include "H5Rpublic.h"
 
+/* Disable warning about cast increasing the alignment of the target type,
+ * that's _exactly_ what this code is probing.  -QAK
+ */
+H5_GCC_DIAG_OFF(cast-align)
+
 #if defined(__has_attribute)
 # if __has_attribute(no_sanitize_address)
 #  define HDF_NO_UBSAN __attribute__((no_sanitize_address))
@@ -216,25 +224,6 @@ precision (detected_t *d)
  *
  * Return:      void
  *
- * Modifications:
- *
- *    Robb Matzke, 4 Nov 1996
- *    The INFO.perm now contains `-1' for bytes that aren't used and
- *    are always zero.  This happens on the Cray for `short' where
- *    sizeof(short) is 8, but only the low-order 4 bytes are ever used.
- *
- *    Robb Matzke, 4 Nov 1996
- *    Added a `padding' field to indicate how many zero bytes appear to
- *    the left (N) or right (-N) of the value.
- *
- *    Robb Matzke, 5 Nov 1996
- *    Removed HFILE and CFILE arguments.
- *
- *      Neil Fortner, 6 Sep 2013
- *      Split macro into DETECT_I and DETECT_BYTE macros, extracted
- *      common code into DETECT_I_BYTE_CORE.  This was done to remove
- *      "will never be executed" warnings.
- *
  *-------------------------------------------------------------------------
  */
 #define DETECT_I_BYTE_CORE(TYPE,VAR,INFO,DETECT_TYPE) {                       \
@@ -1612,12 +1601,6 @@ static int verify_signal_handlers(int signum, void (*handler)(int))
  *
  * Return:      Success:    EXIT_SUCCESS
  *
- * Modifications:
- *    Some compilers, e.g., Intel C v7.0, took a long time to compile
- *      with optimization when a module routine contains many code lines.
- *      Divide up all those types detections macros into subroutines, both
- *      to avoid the compiler optimization error and cleaner codes.
- *
  *-------------------------------------------------------------------------
  */
 int HDF_NO_UBSAN
@@ -1702,3 +1685,4 @@ main(int argc, char *argv[])
     return EXIT_SUCCESS;
 }
 
+H5_GCC_DIAG_ON(cast-align)
