@@ -12,9 +12,9 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Wednesday, April  8, 1998
- * Modified:	Albert Cheng <acheng@hdfgroup.org>
+ * Modified:	Albert Cheng
  * 		September 11, 2010
  */
 /*
@@ -69,7 +69,7 @@
 #   define GB8LL	0	/*cannot do the test*/
 #endif
 
-/* Define Small, Large, Extra Large, Huge File which 
+/* Define Small, Large, Extra Large, Huge File which
  * corrspond to less than 2GB, 2GB, 4GB, and tens of GB file size.
  * NO_FILE stands for "no file" to be tested.
  */
@@ -281,8 +281,7 @@ error:
  *      'name' in the code below, but early (4.4.7, at least) gcc only
  *      allows diagnostic pragmas to be toggled outside of functions.
  */
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+H5_GCC_DIAG_OFF(format-nonliteral)
 static int
 enough_room(hid_t fapl)
 {
@@ -323,7 +322,7 @@ done:
 
     return ret_value;
 }
-#pragma GCC diagnostic pop
+H5_GCC_DIAG_ON(format-nonliteral)
 
 
 /*-------------------------------------------------------------------------
@@ -634,7 +633,7 @@ error:
     return 1;
 } /* end test_sec2() */
 
-static int 
+static int
 test_stdio(hid_t fapl)
 {
     char	filename[1024];
@@ -804,10 +803,10 @@ main (int ac, char **av)
 
     /* Choose random # seed */
     seed = (unsigned long)HDtime(NULL);
-#ifdef QAK
+#if 0
     /* seed = (unsigned long)1155438845; */
     HDfprintf(stderr, "Random # seed was: %lu\n", seed);
-#endif /* QAK */
+#endif
     HDsrandom((unsigned)seed);
 
     /* run VFD-specific test */
