@@ -1664,7 +1664,7 @@ init_invalid_configs(void) {
     configs[13].lower_hr_threshold          = 1.00000001f;
 
     /* 14 -- increment too small */
-    configs[14].increment                   = H5_DOUBLE(0.999999999999);
+    configs[14].increment                   = 0.999999999999;
 
     /* 15 -- invalid flash_incr_mode */
     configs[15].flash_incr_mode             = (enum H5C_cache_flash_incr_mode)-1;
@@ -1697,7 +1697,7 @@ init_invalid_configs(void) {
 
     /* 23 -- decrement too big */
     configs[23].decr_mode                   = H5C_decr__threshold;
-    configs[23].decrement                   = H5_DOUBLE(1.0000000001);
+    configs[23].decrement                   = 1.0000000001;
 
     /* 24 -- epochs_before_eviction too small */
     configs[24].epochs_before_eviction      = 0;
@@ -1709,13 +1709,13 @@ init_invalid_configs(void) {
     configs[26].empty_reserve               = -0.0000000001f;
 
     /* 27 -- empty_reserve too big */
-    configs[27].empty_reserve               = H5_DOUBLE(1.00000000001);
+    configs[27].empty_reserve               = 1.00000000001;
 
     /* 28 -- upper_hr_threshold too small */
     configs[28].upper_hr_threshold          = -0.000000001f;
 
     /* 29 -- upper_hr_threshold too big */
-    configs[29].upper_hr_threshold          = H5_DOUBLE(1.00000001);
+    configs[29].upper_hr_threshold          = 1.00000001;
 
     /* 30 -- upper_hr_threshold <= lower_hr_threshold */
     configs[30].lower_hr_threshold          = 0.9f;
