@@ -700,7 +700,7 @@ test_trivial(const hid_t dxpl_id_simple)
                 FAIL_PUTS_ERROR("    ERROR: Conversion failed to match computed data\n");
         }
 
-    PASSED()
+    PASSED();
 
     TESTING("data transform, trivial transform, with type conversion")
     if(H5Dread(dset_id_float, H5T_NATIVE_INT, H5S_ALL, H5S_ALL,
@@ -712,7 +712,7 @@ test_trivial(const hid_t dxpl_id_simple)
                 FAIL_PUTS_ERROR("    ERROR: Conversion failed to match computed data\n")
         }
 
-    PASSED()
+    PASSED();
 
     return 0;
 error:
@@ -739,7 +739,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
     if(HDstrcmp(c_to_f, ptrgetTest) != 0)
         FAIL_PUTS_ERROR("    ERROR: Data transform failed to match what was set\n")
 
-    PASSED()
+    PASSED();
 
     HDfree(ptrgetTest);
     ptrgetTest = NULL;
@@ -759,7 +759,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
                 FAIL_PUTS_ERROR("    ERROR: Conversion failed to match computed data\n")
         }
 
-    PASSED()
+    PASSED();
 
     TESTING("H5Pget_data_transform, after resetting transform property")
 
@@ -770,7 +770,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
     if(HDstrcmp(simple, ptrgetTest) != 0)
         FAIL_PUTS_ERROR("    ERROR: Data transform failed to match what was set\n")
 
-    PASSED()
+    PASSED();
 
     HDfree(ptrgetTest);
     ptrgetTest = NULL;
@@ -806,7 +806,7 @@ test_set(void)
     H5Eset_auto2(H5E_DEFAULT, NULL, NULL);
 
     if(H5Pget_data_transform(dxpl_id, ptrgetTest, HDstrlen(str) + 1) < 0)
-        PASSED()
+        PASSED();
     else
         FAIL_PUTS_ERROR("    ERROR: Data transform get before set succeeded (it shouldn't have)\n");
 
