@@ -11,11 +11,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Programmer:  Dana Robinson
- *              Spring 2016
- *
- * Purpose:     Tests the basic operation of the evict-on-close cache
+/* Purpose:     Tests the basic operation of the evict-on-close cache
  *              behavior. Tests that ensure the tagging is handled correctly
  *              are located in cache.c.
  */
@@ -76,7 +72,7 @@ const char *FILENAMES[] = {
 #define SUBGROUP_NAME_SIZE          16
 
 /* Prototypes */
-static hbool_t verify_tag_not_in_cache(H5F_t *f, haddr_t tag);
+static hbool_t verify_tag_not_in_cache(const H5F_t *f, haddr_t tag);
 static herr_t check_evict_on_close_api(void);
 static hid_t generate_eoc_test_file(hid_t fapl_id);
 static herr_t check_dset_scheme(hid_t fid, const char *dset_name);
@@ -91,13 +87,10 @@ static herr_t check_group_layout(hid_t fid, const char *group_name);
  *
  * Return:      TRUE/FALSE
  *
- * Programmer:  Dana Robinson
- *              Fall 2016
- *
  *-------------------------------------------------------------------------
  */
-static hbool_t
-verify_tag_not_in_cache(H5F_t *f, haddr_t tag)
+static H5_ATTR_PURE hbool_t
+verify_tag_not_in_cache(const H5F_t *f, haddr_t tag)
 {
     H5C_t *cache_ptr = NULL;                /* cache pointer                */
     int i = 0;                              /* iterator                     */
@@ -114,8 +107,8 @@ verify_tag_not_in_cache(H5F_t *f, haddr_t tag)
                 return TRUE;
             else
                 entry_ptr = entry_ptr->ht_next;
-        } /* end while */
-    } /* end for */
+        }
+    }
 
     return FALSE;
 } /* end verify_tag_not_in_cache() */
@@ -129,9 +122,6 @@ verify_tag_not_in_cache(H5F_t *f, haddr_t tag)
  * Return:      Success: The file ID of the created file
  *              Failure: -1
  *
- * Programmer:  Dana Robinson
- *              Fall 2016
- *
  *-------------------------------------------------------------------------
  */
 static hid_t
@@ -207,7 +197,7 @@ generate_eoc_test_file(hid_t fapl_id)
             TEST_ERROR;
         if(H5Gclose(gid2) < 0)
             TEST_ERROR;
-    } /* end for */
+    }
 
     if(H5Gclose(gid1) < 0)
         TEST_ERROR;
@@ -303,7 +293,7 @@ generate_eoc_test_file(hid_t fapl_id)
             TEST_ERROR;
         if(H5Gclose(gid2) < 0)
             TEST_ERROR;
-    } /* end for */
+    }
 
     if(H5Gclose(gid1) < 0)
         TEST_ERROR;
@@ -593,9 +583,6 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -710,9 +697,6 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -759,7 +743,7 @@ check_dset_scheme(hid_t fid, const char *dset_name)
         TEST_ERROR;
 
     /* Record the number of cache entries */
-    during = file_ptr->shared->cache->index_len; 
+    during = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
     HDprintf("\nCACHE AFTER DATA READ (WHILE OPEN):\n");
@@ -815,9 +799,6 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Spring 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -873,7 +854,7 @@ check_evict_on_close_api(void)
 
     /* ensure an invalid plist fails */
     H5E_BEGIN_TRY {
-        status = H5Pget_evict_on_close((hid_t)-1, &evict_on_close);
+        status = H5Pget_evict_on_close(H5I_INVALID_HID, &evict_on_close);
     } H5E_END_TRY;
     if(status >= 0)
         FAIL_PUTS_ERROR("H5Pget_evict_on_close() accepted invalid hid_t.");
@@ -897,9 +878,6 @@ error:
  *
  * Return:      EXIT_FAILURE/EXIT_SUCCESS
  *
- * Programmer:  Dana Robinson
- *              Spring 2016
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -979,7 +957,7 @@ main(void)
 
     HDprintf("All evict-on-close tests passed.\n");
 
-    return EXIT_SUCCESS;
+    HDexit(EXIT_SUCCESS);
 
 error:
 
@@ -992,7 +970,7 @@ error:
         H5Pclose(fapl_id);
     } H5E_END_TRY;
 
-    return EXIT_FAILURE;
+    HDexit(EXIT_FAILURE);
 
 } /* end main() */
 
@@ -1007,9 +985,6 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Spring 2017
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1052,9 +1027,6 @@ error:
  *
  * Return:      EXIT_FAILURE/EXIT_SUCCESS
  *
- * Programmer:  Dana Robinson
- *              Spring 2016
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1076,14 +1048,14 @@ main(void)
     HDprintf("All evict-on-close tests passed.\n");
     HDprintf("Note that EoC is not supported under parallel so most tests are skipped.\n");
 
-    return EXIT_SUCCESS;
+    HDexit(EXIT_SUCCESS);
 
 error:
 
     HDprintf("***** %u evict-on-close test%s FAILED! *****\n",
         nerrors, nerrors > 1 ? "S" : "");
 
-    return EXIT_FAILURE;
+    HDexit(EXIT_FAILURE);
 
 } /* main() - parallel */
 
