@@ -12,7 +12,7 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Friday, October 23, 1998
  *
  * Purpose:	This is the first half of a two-part test that makes sure
@@ -99,7 +99,7 @@ create_file(const char *filename, hid_t fapl_id, hbool_t swmr)
 
     if(H5Gclose(top_gid) < 0)
         STACK_ERROR
-    
+
     return fid;
 
 error:
@@ -185,7 +185,7 @@ error:
  *              a variety of situations.
  *
  *              Part 1 of a two-part H5Fflush() test.
- *   
+ *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
  * Programmer:	Robb Matzke
@@ -209,7 +209,7 @@ main(void)
 
     /* Check if the current VFD supports SWMR */
     driver = HDgetenv("HDF5_DRIVER");
-    vfd_supports_swmr = H5FD_supports_swmr_test(driver);
+    vfd_supports_swmr = H5FD__supports_swmr_test(driver);
 
     /*************************************************/
     /* NOTE: Not closing the file ID is intentional! */
