@@ -37,7 +37,7 @@ main(void)
     hid_t acpl1;	       	/* attribute create prop. list */
 
     herr_t ret = 0;
-    hsize_t chunk_size = 16384;	/* chunk size */ 
+    hsize_t chunk_size = 16384;	/* chunk size */
     int fill = 2;            /* Fill value */
     hsize_t max_size[1];        /* data space maximum size */
     size_t nslots = 521 * 2;
@@ -129,22 +129,22 @@ main(void)
         assert(ret > 0);
 
     max_size[0] = 100;
-    if((ret = H5Pset_external(dcpl1, "ext1.data", (off_t)0, 
+    if((ret = H5Pset_external(dcpl1, "ext1.data", (off_t)0,
                          (hsize_t)(max_size[0] * sizeof(int)/4))) < 0)
         assert(ret > 0);
-    if((ret = H5Pset_external(dcpl1, "ext2.data", (off_t)0, 
+    if((ret = H5Pset_external(dcpl1, "ext2.data", (off_t)0,
                          (hsize_t)(max_size[0] * sizeof(int)/4))) < 0)
         assert(ret > 0);
-    if((ret = H5Pset_external(dcpl1, "ext3.data", (off_t)0, 
+    if((ret = H5Pset_external(dcpl1, "ext3.data", (off_t)0,
                          (hsize_t)(max_size[0] * sizeof(int)/4))) < 0)
         assert(ret > 0);
-    if((ret = H5Pset_external(dcpl1, "ext4.data", (off_t)0, 
+    if((ret = H5Pset_external(dcpl1, "ext4.data", (off_t)0,
                          (hsize_t)(max_size[0] * sizeof(int)/4))) < 0)
         assert(ret > 0);
 
     if((ret = encode_plist(dcpl1, little_endian, word_length, "testfiles/plist_files/dcpl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(dcpl1)) < 0)
          assert(ret > 0);
@@ -156,13 +156,13 @@ main(void)
 
     if((ret = encode_plist(dapl1, little_endian, word_length, "testfiles/plist_files/def_dapl_")) < 0)
         assert(ret > 0);
-        
+
     if((ret = H5Pset_chunk_cache(dapl1, nslots, nbytes, w0)) < 0)
         assert(ret > 0);
 
     if((ret = encode_plist(dapl1, little_endian, word_length, "testfiles/plist_files/dapl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(dapl1)) < 0)
          assert(ret > 0);
@@ -197,7 +197,7 @@ main(void)
 
     if((ret = encode_plist(dxpl1, little_endian, word_length, "testfiles/plist_files/dxpl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(dxpl1)) < 0)
          assert(ret > 0);
@@ -228,7 +228,7 @@ main(void)
 
     if((ret = encode_plist(gcpl1, little_endian, word_length, "testfiles/plist_files/gcpl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(gcpl1)) < 0)
          assert(ret > 0);
@@ -245,7 +245,7 @@ main(void)
 
     if((ret = encode_plist(lcpl1, little_endian, word_length, "testfiles/plist_files/lcpl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(lcpl1)) < 0)
         assert(ret > 0);
@@ -268,7 +268,7 @@ main(void)
 
     if((ret = encode_plist(ocpypl1, little_endian, word_length, "testfiles/plist_files/ocpypl_")) < 0)
         assert(ret > 0);
-        
+
     /* release resource */
     if((ret = H5Pclose(ocpypl1)) < 0)
          assert(ret > 0);
@@ -461,7 +461,7 @@ encode_plist(hid_t plist_id, int little_endian, int word_length, const char *fil
     herr_t ret = 0;
     void *temp_buf = NULL;
     size_t temp_size = 0;
-    ssize_t write_size;
+    ssize_t H5_ATTR_NDEBUG_UNUSED write_size;
     char filename[1024];
 
     /* Generate filename */
@@ -485,7 +485,7 @@ encode_plist(hid_t plist_id, int little_endian, int word_length, const char *fil
     HDassert(write_size == (ssize_t)temp_size);
 
     HDclose(fd);
-    
+
     HDfree(temp_buf);
 
     return 1;
