@@ -19,6 +19,13 @@
 #define H5I_FRIEND        /*suppress error about including H5Ipkg      */
 #include "H5Ipkg.h"
 
+static herr_t
+free_wrapper(void *p)
+{
+    HDfree(p);
+    return SUCCEED;
+}
+
 /* Test basic functionality of registering and deleting types and IDs */
 static int basic_id_test(void)
 {
@@ -69,7 +76,7 @@ static int basic_id_test(void)
         goto out;
 
     /* Register a type */
-    myType = H5Iregister_type((size_t)64, 0, (H5I_free_t) free );
+    myType = H5Iregister_type((size_t)64, 0, free_wrapper);
 
     CHECK(myType, H5I_BADID, "H5Iregister_type");
     if(myType == H5I_BADID)
@@ -163,7 +170,7 @@ static int basic_id_test(void)
     H5E_END_TRY
 
     /* Register another type and another object in that type */
-    myType = H5Iregister_type((size_t)64, 0, (H5I_free_t) free );
+    myType = H5Iregister_type((size_t)64, 0, free_wrapper);
 
     CHECK(myType, H5I_BADID, "H5Iregister_type");
     if(myType == H5I_BADID)
@@ -238,7 +245,7 @@ out:
 
 
     /* A dummy search function for the next test */
-static int test_search_func(void H5_ATTR_UNUSED * ptr1, void H5_ATTR_UNUSED * ptr2) { return 0; }
+static int test_search_func(void H5_ATTR_UNUSED * ptr1, hid_t H5_ATTR_UNUSED id, void H5_ATTR_UNUSED * ptr2) { return 0; }
 
     /* Ensure that public functions cannot access "predefined" ID types */
 static int id_predefined_test(void )
@@ -251,7 +258,10 @@ static int id_predefined_test(void )
 
     testObj = HDmalloc(sizeof(int));
 
-    /* Try to perform illegal functions on various predefined types */
+    /*
+     * Attempt to perform public functions on various library types
+     */
+
     H5E_BEGIN_TRY
         testID = H5Iregister(H5I_FILE, testObj);
     H5E_END_TRY
@@ -261,7 +271,7 @@ static int id_predefined_test(void )
         goto out;
 
     H5E_BEGIN_TRY
-        testPtr = H5Isearch(H5I_GENPROP_LST, (H5I_search_func_t) test_search_func, testObj);
+        testPtr = H5Isearch(H5I_GENPROP_LST, test_search_func, testObj);
     H5E_END_TRY
 
     CHECK_PTR_NULL(testPtr, "H5Isearch");
@@ -292,7 +302,26 @@ static int id_predefined_test(void )
     if(testErr >= 0)
         goto out;
 
-    /* Create a datatype ID and try to perform illegal functions on it */
+    H5E_BEGIN_TRY
+        testErr = H5Itype_exists(H5I_GROUP);
+    H5E_END_TRY
+
+    VERIFY(testErr, -1, "H5Itype_exists");
+    if(testErr != -1)
+        goto out;
+
+    H5E_BEGIN_TRY
+        testErr = H5Itype_exists(H5I_ATTR);
+    H5E_END_TRY
+
+    VERIFY(testErr, -1, "H5Itype_exists");
+    if(testErr != -1)
+        goto out;
+
+    /*
+     * Create a datatype ID and try to perform illegal functions on it
+     */
+
     typeID = H5Tcreate(H5T_OPAQUE, (size_t)42);
     CHECK(typeID, H5I_INVALID_HID, "H5Tcreate");
     if(typeID == H5I_INVALID_HID)
@@ -317,7 +346,7 @@ static int id_predefined_test(void )
     H5Tclose(typeID);
 
     /* testObj was never registered as an atom, so it will not be
-         * automatically freed. */
+     * automatically freed. */
     HDfree(testObj);
     return 0;
 
@@ -470,13 +499,13 @@ static int test_id_type_list(void)
     H5I_type_t testType;
     int i;    /* Just a counter variable */
 
-    startType = H5Iregister_type((size_t)8, 0, (H5I_free_t) free );
+    startType = H5Iregister_type((size_t)8, 0, free_wrapper);
     CHECK(startType, H5I_BADID, "H5Iregister_type");
     if(startType == H5I_BADID)
         goto out;
 
     /* Sanity check */
-    if(startType >= H5I_MAX_NUM_TYPES || startType < H5I_NTYPES)
+    if((int)startType >= H5I_MAX_NUM_TYPES || startType < H5I_NTYPES)
     {
         /* Error condition, throw an error */
         CHECK(1, 1, "H5Iregister_type");
@@ -485,7 +514,7 @@ static int test_id_type_list(void)
     /* Create types up to H5I_MAX_NUM_TYPES */
     for(i = startType + 1; i < H5I_MAX_NUM_TYPES; i++)
     {
-        currentType = H5Iregister_type((size_t)8, 0, (H5I_free_t) free );
+        currentType = H5Iregister_type((size_t)8, 0, free_wrapper);
         CHECK(currentType, H5I_BADID, "H5Iregister_type");
         if(currentType == H5I_BADID)
             goto out;
@@ -494,7 +523,7 @@ static int test_id_type_list(void)
     /* Wrap around to low type ID numbers */
     for(i = H5I_NTYPES; i < startType; i++)
     {
-        currentType = H5Iregister_type((size_t)8, 0, (H5I_free_t) free );
+        currentType = H5Iregister_type((size_t)8, 0, free_wrapper);
         CHECK(currentType, H5I_BADID, "H5Iregister_type");
         if(currentType == H5I_BADID)
             goto out;
@@ -502,7 +531,7 @@ static int test_id_type_list(void)
 
     /* There should be no room at the inn for a new ID type*/
     H5E_BEGIN_TRY
-        testType = H5Iregister_type((size_t)8, 0, (H5I_free_t) free );
+        testType = H5Iregister_type((size_t)8, 0, free_wrapper);
     H5E_END_TRY
 
     VERIFY(testType, H5I_BADID, "H5Iregister_type");
@@ -511,7 +540,7 @@ static int test_id_type_list(void)
 
     /* Now delete a type and try to insert again */
     H5Idestroy_type(H5I_NTYPES);
-    testType = H5Iregister_type((size_t)8, 0, (H5I_free_t) free );
+    testType = H5Iregister_type((size_t)8, 0, free_wrapper);
 
     VERIFY(testType, H5I_NTYPES, "H5Iregister_type");
     if(testType != H5I_NTYPES)
