@@ -77,86 +77,23 @@
 /* Dataset dimensions */
 #define SM_HEIGHT      2   /* K */
 #define LG_HEIGHT      4   /* N */
-#define SM_LG_HEIGHT   6   /* SM_HEIGHT + LG_HEIGHT */
 #define FULL_HEIGHT    18  /* (3 * K) + (3 * N) */
-#define HALF_HEIGHT    9
 #define WIDTH          8   /* M */
-#define HALF_WIDTH     4
-
-/* Max number of planes in the dataset */
-#define N_MAX_PLANES   H5S_UNLIMITED
 
 /* Number of planes each writer will write */
 #define N_PLANES_TO_WRITE   25
 
-/* Dataset datatypes */
-#define SOURCE_DATATYPE    H5T_STD_I32LE
-#define VDS_DATATYPE       H5T_STD_I32LE
-
-/* Starting size of datasets, both source and VDS */
-static hsize_t DIMS[N_SOURCES][RANK] = {
-    {0, SM_HEIGHT, WIDTH},
-    {0, LG_HEIGHT, WIDTH},
-    {0, SM_HEIGHT, WIDTH},
-    {0, LG_HEIGHT, WIDTH},
-    {0, SM_HEIGHT, WIDTH},
-    {0, LG_HEIGHT, WIDTH}
-};
-static hsize_t VDS_DIMS[RANK] = {0, FULL_HEIGHT, WIDTH};
-
-/* Maximum size of datasets, both source and VDS.
- * NOTE: Theoretical (i.e.: H5S_UNLIMITED), not the actual max
- * number of planes written out by the writers before they stop.
- * That number is specified separately.
- */
-static hsize_t MAX_DIMS[N_SOURCES][RANK] = {
-    {N_MAX_PLANES, SM_HEIGHT, WIDTH},
-    {N_MAX_PLANES, LG_HEIGHT, WIDTH},
-    {N_MAX_PLANES, SM_HEIGHT, WIDTH},
-    {N_MAX_PLANES, LG_HEIGHT, WIDTH},
-    {N_MAX_PLANES, SM_HEIGHT, WIDTH},
-    {N_MAX_PLANES, LG_HEIGHT, WIDTH}
-};
-static hsize_t VDS_MAX_DIMS[RANK] = {N_MAX_PLANES, FULL_HEIGHT, WIDTH};
-
 /* Planes */
-static hsize_t PLANES[N_SOURCES][RANK] = {
-    {1, SM_HEIGHT, WIDTH},
-    {1, LG_HEIGHT, WIDTH},
-    {1, SM_HEIGHT, WIDTH},
-    {1, LG_HEIGHT, WIDTH},
-    {1, SM_HEIGHT, WIDTH},
-    {1, LG_HEIGHT, WIDTH}
-};
+H5TEST_DLLVAR hsize_t PLANES[N_SOURCES][RANK];
 
 /* File names for source datasets */
-static char FILE_NAMES[N_SOURCES][NAME_LEN] = {
-    {"vds_swmr_src_a.h5"},
-    {"vds_swmr_src_b.h5"},
-    {"vds_swmr_src_c.h5"},
-    {"vds_swmr_src_d.h5"},
-    {"vds_swmr_src_e.h5"},
-    {"vds_swmr_src_f.h5"}
-};
+H5TEST_DLLVAR char FILE_NAMES[N_SOURCES][NAME_LEN];
 
 /* VDS file name */
-static char VDS_FILE_NAME[NAME_LEN] = "vds_swmr.h5";
+H5TEST_DLLVAR char VDS_FILE_NAME[NAME_LEN];
 
 /* Dataset names */
-static char SOURCE_DSET_NAME[NAME_LEN] = "source_dset";
-static char SOURCE_DSET_PATH[NAME_LEN] = "/source_dset";
-static char VDS_DSET_NAME[NAME_LEN]    = "vds_dset";
-
-/* Fill values */
-static int32_t FILL_VALUES[N_SOURCES] = {
-    -1,
-    -2,
-    -3,
-    -4,
-    -5,
-    -6
-};
-static int32_t VDS_FILL_VALUE = -9;
-
+H5TEST_DLLVAR char SOURCE_DSET_PATH[NAME_LEN];
+H5TEST_DLLVAR char VDS_DSET_NAME[NAME_LEN];
 #endif /* VDS_SWMR_H */
 
