@@ -47,11 +47,11 @@ main (int argc, char **argv)
 
     MPI_Init(&argc, &argv);
     MPI_Comm_size(comm, &mpi_size);
-    MPI_Comm_rank(comm, &mpi_rank);  
+    MPI_Comm_rank(comm, &mpi_rank);
 
     if(MAINPROCESS)
 	TESTING("proper shutdown of HDF5 library");
- 
+
     /* Set up file access property list with parallel I/O access */
     fapl = H5Pcreate(H5P_FILE_ACCESS);
     VRFY((fapl >= 0), "H5Pcreate succeeded");
@@ -120,14 +120,14 @@ main (int argc, char **argv)
     HDremove(filename);
 
     /* release data buffers */
-    if(data_array) 
+    if(data_array)
         HDfree(data_array);
 
     nerrors += GetTestNumErrs();
 
     if(MAINPROCESS) {
         if(0 == nerrors)
-            PASSED()
+            PASSED();
         else
 	    H5_FAILED()
     }
