@@ -12,7 +12,7 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Raymond Lu <slu@ncsa.uiuc.edu>
+ * Programmer:	Raymond Lu
  *		Friday, Oct 3, 2004
  *
  * Purpose:	Tests performance of metadata
@@ -313,7 +313,7 @@ create_dsets(hid_t file)
      * Create a dataset using the default dataset creation properties.
      */
     for(i = 0; i < NUM_DSETS; i++) {
-	sprintf(dset_name, "dataset %d", i);
+	HDsprintf(dset_name, "dataset %d", i);
     	if((dataset = H5Dcreate2(file, dset_name, H5T_NATIVE_DOUBLE, space,
                 H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
             goto error;
@@ -378,14 +378,14 @@ create_attrs_1(void)
      * Create all(user specifies the number) attributes for each dataset
      */
     for(i = 0; i < NUM_DSETS; i++) {
-	sprintf(dset_name, "dataset %d", i);
+	HDsprintf(dset_name, "dataset %d", i);
         open_t.start = retrieve_time();
 	if((dataset = H5Dopen2(file, dset_name, H5P_DEFAULT)) < 0)
 		goto error;
 	perf(&open_t, open_t.start, retrieve_time());
 
 	for(j = 0; j < NUM_ATTRS; j++) {
-            sprintf(attr_name, "all attrs for each dset %d", j);
+            HDsprintf(attr_name, "all attrs for each dset %d", j);
             attr_t.start = retrieve_time();
             if((attr = H5Acreate2(dataset, attr_name, H5T_NATIVE_DOUBLE,
                     small_space, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -422,7 +422,7 @@ create_attrs_1(void)
             attr_t.avg  = attr_t.total / (NUM_ATTRS*NUM_DSETS);
 
         /* Print out the performance result */
-        fprintf(stderr, "1.  Create %d attributes for each of %d existing datasets\n",
+        HDfprintf(stderr, "1.  Create %d attributes for each of %d existing datasets\n",
             NUM_ATTRS, NUM_DSETS);
         print_perf(open_t, close_t, attr_t);
     }
@@ -480,7 +480,7 @@ create_attrs_2(void)
      * Create all(user specifies the number) attributes for each new dataset
      */
     for(i = 0; i < NUM_DSETS; i++) {
-	sprintf(dset_name, "dataset %d", i);
+	HDsprintf(dset_name, "dataset %d", i);
         create_t.start = retrieve_time();
    	if((dataset = H5Dcreate2(file, dset_name, H5T_NATIVE_DOUBLE,
                 space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -488,7 +488,7 @@ create_attrs_2(void)
 	perf(&create_t, create_t.start, retrieve_time());
 
 	for(j = 0; j < NUM_ATTRS; j++) {
-            sprintf(attr_name, "all attrs for each dset %d", j);
+            HDsprintf(attr_name, "all attrs for each dset %d", j);
             attr_t.start = retrieve_time();
             if((attr = H5Acreate2(dataset, attr_name, H5T_NATIVE_DOUBLE,
                     small_space, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -525,7 +525,7 @@ create_attrs_2(void)
             attr_t.avg = attr_t.total / (NUM_ATTRS*NUM_DSETS);
 
         /* Print out the performance result */
-        fprintf(stderr, "2.  Create %d attributes for each of %d new datasets\n",
+        HDfprintf(stderr, "2.  Create %d attributes for each of %d new datasets\n",
             NUM_ATTRS, NUM_DSETS);
         print_perf(create_t, close_t, attr_t);
     }
@@ -593,14 +593,14 @@ create_attrs_3(void)
 
     for(i = 0; i < loop_num; i++) {
     	for(j = 0; j < NUM_DSETS; j++) {
-            sprintf(dset_name, "dataset %d", j);
+            HDsprintf(dset_name, "dataset %d", j);
             open_t.start = retrieve_time();
             if((dataset = H5Dopen2(file, dset_name, H5P_DEFAULT)) < 0)
                 goto error;
             perf(&open_t, open_t.start, retrieve_time());
 
             for(k = 0; k < BATCH_ATTRS; k++) {
-                sprintf(attr_name, "some attrs for each dset %d %d", i, k);
+                HDsprintf(attr_name, "some attrs for each dset %d %d", i, k);
                 attr_t.start = retrieve_time();
                 if((attr = H5Acreate2(dataset, attr_name, H5T_NATIVE_DOUBLE,
                         small_space, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -637,7 +637,7 @@ create_attrs_3(void)
         attr_t.avg = attr_t.total / (NUM_ATTRS*NUM_DSETS);
 
         /* Print out the performance result */
-        fprintf(stderr, "3.  Create %d attributes for each of %d existing datasets for %d times\n",
+        HDfprintf(stderr, "3.  Create %d attributes for each of %d existing datasets for %d times\n",
             BATCH_ATTRS, NUM_DSETS, loop_num);
         print_perf(open_t, close_t, attr_t);
     }
@@ -750,12 +750,12 @@ void perf(p_time *perf_t, double start_t, double end_t)
  */
 void print_perf(p_time open_t, p_time close_t, p_time attr_t)
 {
-    fprintf(stderr, "\t%s:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
+    HDfprintf(stderr, "\t%s:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
 		open_t.func, open_t.avg, open_t.max, open_t.min);
-    fprintf(stderr, "\tH5Dclose:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
+    HDfprintf(stderr, "\tH5Dclose:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
 		close_t.avg, close_t.max, close_t.min);
     if(NUM_ATTRS)
-        fprintf(stderr, "\tH5A(create & close):\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
+        HDfprintf(stderr, "\tH5A(create & close):\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n",
 		attr_t.avg, attr_t.max, attr_t.min);
 }
 
@@ -799,7 +799,7 @@ main(int argc, char **argv)
 #ifdef H5_HAVE_PARALLEL
     if (facc_type == FACC_DEFAULT || (facc_type != FACC_DEFAULT && MAINPROCESS))
 #endif /*H5_HAVE_PARALLEL*/
-        fprintf(stderr, "\t\tPerformance result of metadata for datasets and attributes\n\n");
+        HDfprintf(stderr, "\t\tPerformance result of metadata for datasets and attributes\n\n");
 
     fapl = H5Pcreate (H5P_FILE_ACCESS);
 #ifdef H5_HAVE_PARALLEL
